//--------------------------------------------------------------
//
//  WIN32API.PRG
//
//  This file contains Windows API function prototypes for
//  use with Visual dBASE. By simply DOing the file, all of
//  the functions are prototyped. To prototype only a section
//  of functions, you can use one of the section constants
//  defined at the beginning of WIN32API.H.  You can combine
//  these constants to prototype multiple sections. The type
//  and constant declarations for the Win32 API are declared
//  in WIN32API.H.
//
//  USAGE:  (in a file)
//          #include <WIN32API.H>
//          DO WIN32API.PRG    // to prototype all functions
//
//          // prototype only the Registry functions:
//          DO WIN32API.PRG WITH WIN32API_REGISTRY
//
//          // prototype the GDI and INI file functions
//          DO WIN32API.PRG with WIN32API_ALLGDI + WIN32API_INIFILE
//
//
//  Visual dBASE Samples Group
//
//  $Revision:   1.3  $
//
//  Portions copyright (c) 1990-1995, Microsoft Corp.
//
//--------------------------------------------------------------

parameter lpSection

#include <WINDEF.H>
#define HWND CHANDLE  // not in WINDEF.H due to conflict with dBASE property

//
//  This program file is intended to be executed where ever it is 
//  vital that the API functions be externed, rather than being 
//  #included.  The variable on _app reduces the execution speed 
//  of the final code, by only doing the externs one time. 
//

if TYPE('_app.Win32APIAlreadyRun') == 'U' OR ( NOT _app.Win32APIAlreadyRun )
   //
   //  If the file is run without conditions then set the _app 
   //  variable so the file is not run again.
   //
   if PCOUNT() == 0
      _app.Win32APIAlreadyRun = true
      lpSection = WIN32API_ALLSECTIONS
   endif   

   if bitand(lpSection, WIN32API_KERNEL) <> 0
      ExternKernel()
   endif

   if bitand(lpSection, WIN32API_INIFILE) <> 0
      ExternIniFile()
   endif


   if bitand(lpSection, WIN32API_ADVAPI) <> 0
      ExternADVAPI()
   endif
 
   if bitand(lpSection, WIN32API_GDI) <> 0
      ExternGDI()
   endif

   if bitand(lpSection, WIN32API_USER) <> 0
      ExternUser()
   endif

   if bitand(lpSection, WIN32API_REGISTRY) <> 0
      ExternRegistry()
   endif

   if bitand(lpSection, WIN32API_NETWORK) <> 0
      ExternNetwork()
   endif  

   if bitand(lpSection, WIN32API_SHELL) <> 0
      ExternShell()
   endif

   if bitand(lpSection, WIN32API_DIALOG) <> 0
      ExternDialog()
   endif

endif   // type('_app.Win32APIAlreadyRun') = 'U'

function ExternKernel
   //------------------------------------------------------------------
   //   Adapted from winbase.h 
   //   This section defines the 32-Bit Windows Base APIs
   //------------------------------------------------------------------
 
   extern LONG        InterlockedIncrement( LPLONG ) kernel32
   extern LONG        InterlockedDecrement( LPLONG ) kernel32
   extern LONG        InterlockedExchange( LPLONG ) kernel32

// extern BOOL        FreeResource( HGLOBAL ) kernel32      // obsolete
   extern CLONG       LockResource( HGLOBAL ) kernel32
   extern BOOL        FreeLibrary( HMODULE ) kernel32
   extern VOID        FreeLibraryAndExitThread(HMODULE, DWORD) kernel32
   extern BOOL        DisableThreadLibraryCalls(HMODULE) kernel32
   extern CLONG       GetProcAddress(HMODULE, LPCSTR) kernel32
   extern DWORD       GetVersion( VOID ) kernel32

   extern HGLOBAL     GlobalAlloc(UINT, DWORD) kernel32
   extern HGLOBAL     GlobalReAlloc(HGLOBAL, DWORD, UINT) kernel32
   extern DWORD       GlobalSize(HGLOBAL) kernel32
   extern UINT        GlobalFlags(HGLOBAL) kernel32
   extern CLONG       GlobalLock(HGLOBAL) kernel32
   extern HGLOBAL     GlobalHandle(LPCVOID) kernel32
   extern BOOL        GlobalUnlock(HGLOBAL) kernel32
   extern HGLOBAL     GlobalFree(HGLOBAL) kernel32
// extern UINT        GlobalCompact(DWORD) kernel32        // obsolete
// extern VOID        GlobalFix(HGLOBAL) kernel32          // obsolete
// extern VOID        GlobalUnfix(HGLOBAL) kernel32        // obsolete
// extern CLONG       GlobalWire(HGLOBAL)  kernel32       // obsolete
// extern BOOL        GlobalUnWire(HGLOBAL)  kernel32      // obsolete
   extern VOID        GlobalMemoryStatus(LPSTRUCTURE) kernel32

   extern HLOCAL      LocalAlloc(UINT, UINT) kernel32
   extern HLOCAL      LocalReAlloc(HLOCAL, UINT, UINT) kernel32
   extern CLONG       LocalLock(HLOCAL) kernel32
   extern HLOCAL      LocalHandle(LPCVOID) kernel32
   extern BOOL        LocalUnlock(HLOCAL) kernel32
   extern UINT        LocalSize(HLOCAL) kernel32
   extern UINT        LocalFlags(HLOCAL) kernel32
   extern HLOCAL      LocalFree(HLOCAL) kernel32
// extern UINT        LocalShrink(HLOCAL, UINT) kernel32   // obsolete
// extern UINT        LocalCompact(UINT uMinFree) kernel32 // obsolete

   extern BOOL        FlushInstructionCache(HANDLE, LPCVOID, DWORD) kernel32

   extern CLONG       VirtualAlloc(LPVOID, DWORD, DWORD, DWORD) kernel32
   extern BOOL        VirtualFree(LPVOID, DWORD, DWORD) kernel32
   extern BOOL        VirtualProtect(LPVOID, DWORD, DWORD, PDWORD) kernel32
   extern DWORD       VirtualQuery(LPCVOID, PSTRUCTURE, DWORD) kernel32

   extern BOOL        VirtualProtectEx(HANDLE, LPVOID, DWORD, DWORD, ;
                   PDWORD) kernel32

   extern DWORD       VirtualQueryEx(HANDLE, LPCVOID, PSTRUCTURE, ;
                   DWORD) kernel32

   extern HANDLE      HeapCreate(DWORD, DWORD, DWORD) kernel32
   extern BOOL        HeapDestroy(HANDLE) kernel32
   extern CLONG       HeapAlloc(HANDLE, DWORD, DWORD) kernel32
   extern CLONG       HeapReAlloc(HANDLE, DWORD, LPVOID, DWORD) kernel32
   extern BOOL        HeapFree(HANDLE, DWORD, LPVOID) kernel32
   extern DWORD       HeapSize(HANDLE, DWORD, LPCVOID) kernel32

   extern BOOL        HeapValidate(HANDLE, DWORD, LPCVOID) kernel32
   extern UINT        HeapCompact(HANDLE, DWORD) kernel32

   extern HANDLE      GetProcessHeap( VOID ) kernel32

   extern DWORD       GetProcessHeaps(DWORD, PHANDLE) kernel32
   extern BOOL        HeapLock(HANDLE) kernel32
   extern BOOL        HeapUnlock(HANDLE) kernel32
   extern BOOL        HeapWalk(HANDLE, LPSTRUCTURE) kernel32

   extern BOOL        GetBinaryType(LPCSTR, LPDWORD) kernel32 ;
                   from "GetBinaryTypeA"

   extern DWORD       GetShortPathName(LPCSTR, LPSTR, DWORD) kernel32 ;
                   from "GetShortPathNameA"

   extern BOOL        GetProcessAffinityMask(HANDLE, LPDWORD, LPDWORD) kernel32

   extern BOOL        GetProcessTimes(HANDLE, LPSTRUCTURE, LPSTRUCTURE, ;
                   LPSTRUCTURE, LPSTRUCTURE) kernel32
   extern BOOL        GetProcessWorkingSetSize(HANDLE, LPDWORD, ;
                   LPDWORD) kernel32
   extern BOOL        SetProcessWorkingSetSize(HANDLE, DWORD, DWORD) kernel32

   extern HANDLE      OpenProcess(DWORD, BOOL, DWORD) kernel32

   extern HANDLE      GetCurrentProcess( VOID ) kernel32
   extern DWORD       GetCurrentProcessId( VOID ) kernel32
   extern VOID        ExitProcess( UINT ) kernel32

   extern BOOL        TerminateProcess(HANDLE, UINT ) kernel32

   extern BOOL        GetExitCodeProcess(HANDLE, LPDWORD) kernel32
   extern VOID        FatalExit( CINT) kernel32
   extern LPSTR       GetEnvironmentStrings( VOID ) kernel32

   extern BOOL        FreeEnvironmentStrings(LPSTR ) kernel32 ;
                   from "FreeEnvironmentStringsA"

   extern VOID        RaiseException(DWORD, DWORD, DWORD, LPDWORD ) kernel32
   extern LONG        UnhandledExceptionFilter( LPSTRUCTURE ) kernel32
   extern CLONG       SetUnhandledExceptionFilter(LPSTRUCTURE) kernel32

   extern HANDLE      CreateThread(LPSTRUCTURE, DWORD, LPSTRUCTURE, LPVOID, ;
                   DWORD, LPDWORD) kernel32

   extern HANDLE      CreateRemoteThread(HANDLE, LPSTRUCTURE, DWORD, ;
                   LPSTRUCTURE, LPVOID, DWORD, LPDWORD ) kernel32

   extern HANDLE      GetCurrentThread( VOID ) kernel32
   extern DWORD       GetCurrentThreadId( VOID) kernel32

   extern DWORD       SetThreadAffinityMask(HANDLE, DWORD) kernel32
   extern BOOL        SetThreadPriority( HANDLE, CINT ) kernel32
   extern CINT        GetThreadPriority( HANDLE ) kernel32

   extern BOOL        GetThreadTimes(HANDLE, LPSTRUCTURE, LPSTRUCTURE, ;
                   LPSTRUCTURE, LPSTRUCTURE) kernel32

   extern VOID        ExitThread( DWORD ) kernel32
   extern BOOL        TerminateThread(HANDLE, DWORD) kernel32

   extern BOOL        GetExitCodeThread(HANDLE, LPDWORD) kernel32
   extern BOOL        GetThreadSelectorEntry(HANDLE, DWORD, LPSTRUCTURE) kernel32
   extern DWORD       GetLastError( VOID ) kernel32
   extern VOID        SetLastError( DWORD ) kernel32

   extern BOOL        GetOverlappedResult(HANDLE, LPSTRUCTURE, LPDWORD, BOOL) ;
                   kernel32
   extern HANDLE      CreateIoCompletionPort(HANDLE, HANDLE, DWORD, DWORD) ;
                   kernel32
   extern BOOL        GetQueuedCompletionStatus(HANDLE, LPDWORD, LPDWORD, ;
                   LPSTRUCTURE, DWORD) kernel32

   extern BOOL        ReadProcessMemory(HANDLE, LPCVOID, LPVOID, DWORD, ;
                   LPDWORD) kernel32

   extern BOOL        WriteProcessMemory(HANDLE, LPVOID, LPVOID, DWORD, ;
                   LPDWORD ) kernel32

   extern BOOL        GetThreadContext(HANDLE, LPSTRUCTURE) kernel32
   extern BOOL        SetThreadContext(HANDLE, LPSTRUCTURE) kernel32

   extern DWORD       SuspendThread( HANDLE ) kernel32

   extern DWORD       ResumeThread( HANDLE ) kernel32

   extern VOID        DebugBreak( VOID ) kernel32
   extern BOOL        WaitForDebugEvent( LPSTRUCTURE, DWORD ) kernel32
   extern BOOL        ContinueDebugEvent(DWORD, DWORD, DWORD) kernel32

   extern BOOL        DebugActiveProcess( DWORD ) kernel32

   extern VOID        InitializeCriticalSection( LPSTRUCTURE ) kernel32
   extern VOID        EnterCriticalSection( LPSTRUCTURE ) kernel32
   extern VOID        LeaveCriticalSection( LPSTRUCTURE ) kernel32
   extern VOID        DeleteCriticalSection( LPSTRUCTURE ) kernel32

   extern BOOL        SetEvent( HANDLE ) kernel32
   extern BOOL        ResetEvent( HANDLE ) kernel32
   extern BOOL        PulseEvent( HANDLE ) kernel32
   extern BOOL        ReleaseSemaphore( HANDLE, LONG, LPLONG ) kernel32
   extern BOOL        ReleaseMutex( HANDLE ) kernel32
   extern DWORD       WaitForSingleObject(HANDLE, DWORD) kernel32
   extern DWORD       WaitForMultipleObjects(DWORD, LPHANDLE, BOOL, ;
                   DWORD) kernel32

   extern VOID        Sleep( DWORD ) kernel32
   extern HGLOBAL     LoadResource(HMODULE, HRSRC) kernel32
   extern DWORD       SizeofResource(HMODULE, HRSRC) kernel32
   extern ATOM        GlobalDeleteAtom( ATOM ) kernel32
   extern BOOL        InitAtomTable( DWORD ) kernel32
   extern ATOM        DeleteAtom( ATOM ) kernel32
   extern UINT        SetHandleCount( UINT ) kernel32
   extern DWORD       GetLogicalDrives( VOID ) kernel32
   extern BOOL        LockFile(HANDLE, DWORD, DWORD, DWORD, DWORD ) kernel32
   extern BOOL        UnlockFile(HANDLE, DWORD, DWORD, DWORD, DWORD ) kernel32

   extern BOOL        LockFileEx(HANDLE, DWORD, DWORD, DWORD, DWORD, ;
                   LPSTRUCTURE ) kernel32
   extern BOOL        UnlockFileEx(HANDLE, DWORD, DWORD, DWORD, ;
                   LPSTRUCTURE ) kernel32

   extern BOOL        GetFileInformationByHandle(HANDLE, LPSTRUCTURE) kernel32

   extern DWORD       GetFileType( HANDLE ) kernel32
   extern DWORD       GetFileSize(HANDLE, LPDWORD ) kernel32
   extern HANDLE      GetStdHandle( DWORD ) kernel32
   extern BOOL        SetStdHandle(DWORD, HANDLE ) kernel32
   extern BOOL        WriteFile(HANDLE, LPCVOID, DWORD, LPDWORD, LPSTRUCTURE) ;
                   kernel32
   extern BOOL        ReadFile(HANDLE, LPVOID, DWORD, LPDWORD, LPSTRUCTURE) ;
                   kernel32
   extern BOOL        FlushFileBuffers( HANDLE ) kernel32

   extern BOOL        DeviceIoControl(HANDLE, DWORD, LPVOID, DWORD, LPVOID, ;
                   DWORD, LPDWORD, LPSTRUCTURE) kernel32

   extern BOOL        SetEndOfFile( HANDLE ) kernel32
   extern DWORD       SetFilePointer(HANDLE, LONG, PLONG, DWORD ) kernel32
   extern BOOL        FindClose( HANDLE ) kernel32
   extern BOOL        GetFileTime(HANDLE, LPSTRUCTURE, LPSTRUCTURE, ;
                   LPSTRUCTURE ) kernel32
   extern BOOL        SetFileTime(HANDLE, LPSTRUCTURE, LPSTRUCTURE, ;
                   LPSTRUCTURE ) kernel32
   extern BOOL        CloseHandle( HANDLE ) kernel32
   extern BOOL        DuplicateHandle(HANDLE, HANDLE, HANDLE, LPHANDLE, ;
                   DWORD, BOOL, DWORD) kernel32

   extern BOOL        GetHandleInformation(HANDLE, LPDWORD) kernel32
   extern BOOL        SetHandleInformation(HANDLE, DWORD, DWORD) kernel32

   extern DWORD       LoadModule(LPCSTR, LPVOID) kernel32
   extern UINT        WinExec(LPCSTR, UINT) kernel32
   extern BOOL        ClearCommBreak( HANDLE ) kernel32
   extern BOOL        ClearCommError(HANDLE, LPDWORD, LPSTRUCTURE) kernel32
   extern BOOL        SetupComm(HANDLE, DWORD, DWORD) kernel32
   extern BOOL        EscapeCommFunction(HANDLE, DWORD) kernel32

   extern BOOL        GetCommConfig(HANDLE, LPSTRUCTURE, LPDWORD) kernel32

   extern BOOL        GetCommMask(HANDLE, LPDWORD) kernel32
   extern BOOL        GetCommProperties(HANDLE, LPSTRUCTURE) kernel32
   extern BOOL        GetCommModemStatus(HANDLE, LPDWORD) kernel32
   extern BOOL        GetCommState(HANDLE, LPSTRUCTURE) kernel32
   extern BOOL        GetCommTimeouts(HANDLE, LPSTRUCTURE) kernel32
   extern BOOL        PurgeComm(HANDLE, DWORD) kernel32
   extern BOOL        SetCommBreak( HANDLE ) kernel32

   extern BOOL        SetCommConfig(HANDLE, LPSTRUCTURE, DWORD) kernel32

   extern BOOL        SetCommMask(HANDLE, DWORD) kernel32
   extern BOOL        SetCommState(HANDLE, LPSTRUCTURE) kernel32
   extern BOOL        SetCommTimeouts(HANDLE, LPSTRUCTURE) kernel32
   extern BOOL        TransmitCommChar(HANDLE, CHAR) kernel32
   extern BOOL        WaitCommEvent(HANDLE, LPDWORD, LPSTRUCTURE) kernel32

   extern DWORD       SetTapePosition(HANDLE, DWORD, DWORD, DWORD, DWORD, BOOL) kernel32
   extern DWORD       GetTapePosition(HANDLE, DWORD, LPDWORD, LPDWORD, LPDWORD) kernel32
   extern DWORD       PrepareTape(HANDLE, DWORD, BOOL) kernel32
   extern DWORD       EraseTape(HANDLE, DWORD, BOOL) kernel32
   extern DWORD       CreateTapePartition(HANDLE, DWORD, DWORD, DWORD) kernel32
   extern DWORD       WriteTapemark(HANDLE, DWORD, DWORD, BOOL) kernel32
   extern DWORD       GetTapeStatus( HANDLE ) kernel32
   extern DWORD       GetTapeParameters(HANDLE, DWORD, LPDWORD, LPVOID) kernel32
   extern DWORD       SetTapeParameters(HANDLE, DWORD, LPVOID) kernel32

   extern BOOL        Beep(DWORD, DWORD) kernel32

// extern VOID        OpenSound( VOID ) kernel32         // Obsolete
// extern VOID        CloseSound( VOID ) kernel32        // Obsolete
// extern VOID        StartSound( VOID ) kernel32        // Obsolete
// extern VOID        StopSound( VOID ) kernel32         // Obsolete
// extern DWORD       WaitSoundState( DWORD ) kernel32   // Obsolete
// extern DWORD       SyncAllVoices( VOID ) kernel32     // Obsolete
// extern DWORD       CountVoiceNotes( DWORD ) kernel32  // Obsolete
// extern LPDWORD     GetThresholdEvent( VOID ) kernel32            // Obsolete
// extern DWORD       GetThresholdStatus( VOID ) kernel32           // Obsolete
// extern DWORD       SetSoundNoise( DWORD, DWORD ) kernel32        // Obsolete
// extern DWORD       SetVoiceAccent(DWORD, DWORD, DWORD, DWORD, DWORD) kernel32 // Obsolete
// extern DWORD       SetVoiceEnvelope(DWORD, DWORD, DWORD) kernel32     // Obsolete
// extern DWORD       SetVoiceNote(DWORD, DWORD, DWORD, DWORD) kernel32  // Obsolete
// extern DWORD       SetVoiceQueueSize(DWORD, DWORD) kernel32      // Obsolete
// extern DWORD       SetVoiceSound(DWORD, DWORD, DWORD) kernel32   // Obsolete
// extern DWORD       SetVoiceThreshold(DWORD, DWORD) kernel32      // Obsolete

   extern CINT        MulDiv(CINT, CINT, CINT) kernel32
   extern VOID        GetSystemTime( LPSTRUCTURE ) kernel32
   extern VOID        GetSystemTimeAsFileTime( LPSTRUCTURE ) kernel32
   extern BOOL        SetSystemTime( LPSTRUCTURE ) kernel32

   extern VOID        GetLocalTime( LPSTRUCTURE ) kernel32
   extern BOOL        SetLocalTime( LPSTRUCTURE ) kernel32
   extern VOID        GetSystemInfo( LPSTRUCTURE ) kernel32
   extern BOOL        SystemTimeToTzSpecificLocalTime( LPSTRUCTURE, ;
                   LPSTRUCTURE, LPSTRUCTURE) kernel32
   extern DWORD       GetTimeZoneInformation( LPSTRUCTURE ) kernel32
   extern BOOL        SetTimeZoneInformation( LPSTRUCTURE ) kernel32

   //
   // Routines to convert back and forth between system time and 
   // file time
   //
   extern BOOL        SystemTimeToFileTime(LPSTRUCTURE, LPSTRUCTURE) kernel32
   extern BOOL        FileTimeToLocalFileTime(LPSTRUCTURE, LPSTRUCTURE) kernel32
   extern BOOL        LocalFileTimeToFileTime(LPSTRUCTURE, LPSTRUCTURE) kernel32
   extern BOOL        FileTimeToSystemTime(LPSTRUCTURE, LPSTRUCTURE) kernel32
   extern LONG        CompareFileTime(LPSTRUCTURE, LPSTRUCTURE) kernel32
   extern BOOL        FileTimeToDosDateTime(LPSTRUCTURE, LPWORD, LPWORD) kernel32
   extern BOOL        DosDateTimeToFileTime(WORD, WORD, LPSTRUCTURE) kernel32
   extern DWORD       GetTickCount( VOID ) kernel32

   extern BOOL        SetSystemTimeAdjustment(DWORD, BOOL) kernel32
   extern BOOL        GetSystemTimeAdjustment(PDWORD, PDWORD, PBOOL) kernel32

   extern DWORD       FormatMessage(DWORD, LPCVOID, DWORD, DWORD, LPSTR, ;
                   DWORD, CPTR) kernel32  ;
                   from "FormatMessageA"

   extern CLONG       MapViewOfFile(HANDLE, DWORD, DWORD, DWORD, DWORD) kernel32
   extern BOOL        FlushViewOfFile(LPCVOID, DWORD) kernel32
   extern BOOL        UnmapViewOfFile( LPCVOID ) kernel32

   //
   // _l Compat Functions
   //

   extern CINT        lstrcmp(LPCSTR, LPCSTR) kernel32 ;
                   from "lstrcmpA"
   extern CINT        lstrcmpi(LPCSTR, LPCSTR) kernel32 ;
                   from "lstrcmpiA"
   extern LPSTR       lstrcpyn(LPSTR, LPCSTR, CINT) kernel32 ;
                   from "lstrcpynA"
   extern LPSTR       lstrcpy(LPSTR, LPCSTR) kernel32 ;
                   from "lstrcpyA"
   extern LPSTR       lstrcat(LPSTR, LPCSTR) kernel32 ;
                   from "lstrcatA"
   extern CINT        lstrlen( LPCSTR ) kernel32 ;
                   from "lstrlenA"

   extern HFILE       OpenFile(LPCSTR, LPSTRUCTURE, UINT) kernel32
   extern HFILE       _lopen(LPCSTR, CINT) kernel32
   extern HFILE       _lcreat(LPCSTR, CINT) kernel32
   extern UINT        _lread(HFILE, LPVOID, UINT) kernel32
   extern UINT        _lwrite(HFILE, LPCSTR, UINT) kernel32
   extern LONG        _hread(HFILE, LPVOID, LONG) kernel32
   extern LONG        _hwrite(HFILE, LPCSTR, LONG) kernel32
   extern HFILE       _lclose( HFILE ) kernel32
   extern LONG        _llseek(HFILE, LONG, CINT) kernel32

   extern DWORD       TlsAlloc( VOID ) kernel32
   extern CLONG       TlsGetValue( DWORD ) kernel32
   extern BOOL        TlsSetValue(DWORD, LPVOID ) kernel32
   extern BOOL        TlsFree( DWORD ) kernel32
   extern DWORD       SleepEx(DWORD, BOOL) kernel32

   extern DWORD       WaitForSingleObjectEx(HANDLE, DWORD, BOOL) kernel32
   extern DWORD       WaitForMultipleObjectsEx(DWORD, LPHANDLE, BOOL, ;
                   DWORD, BOOL) kernel32
   extern BOOL        ReadFileEx(HANDLE, LPVOID, DWORD, LPSTRUCTURE, ;
                   LPSTRUCTURE) kernel32
   extern BOOL        WriteFileEx(HANDLE, LPCVOID, DWORD, LPSTRUCTURE,  ;
                   LPSTRUCTURE) kernel32
   extern BOOL        BackupRead(HANDLE, LPBYTE, DWORD, LPDWORD, BOOL, ;
                   BOOL, LPVOID) kernel32
   extern BOOL        BackupSeek(HANDLE, DWORD, DWORD, LPDWORD, LPDWORD, ;
                   LPVOID) kernel32
   extern BOOL        BackupWrite(HANDLE, LPBYTE, DWORD, LPDWORD, BOOL, ;
                   BOOL, LPVOID) kernel32
   extern HANDLE      CreateMutex(LPSTRUCTURE, BOOL , LPCSTR) kernel32 ;
                   from "CreateMutexA"
   extern HANDLE      OpenMutex(DWORD, BOOL, LPCSTR) kernel32 ;
                   from "OpenMutexA"
   extern HANDLE      CreateEvent(LPSTRUCTURE, BOOL, BOOL, LPCSTR) kernel32 ;
                   from "CreateEventA"
   extern HANDLE      OpenEvent(DWORD, BOOL, LPCSTR) kernel32 ;
                   from "OpenEventA"
   extern HANDLE      CreateSemaphore(LPSTRUCTURE, LONG, LONG, ;
                   LPCSTR) kernel32 ;
                   from "CreateSemaphoreA"
   extern HANDLE      OpenSemaphore(DWORD, BOOL, LPCSTR) kernel32 ;
                   from "OpenSemaphoreA"

   extern HANDLE      CreateFileMapping(HANDLE, LPSTRUCTURE, DWORD, DWORD, ;
                   DWORD, LPCSTR) kernel32 ;
                   from "CreateFileMappingA"
   extern HANDLE      OpenFileMapping(DWORD, BOOL, LPCSTR) kernel32 ;
                   from "OpenFileMappingA"

   extern DWORD       GetLogicalDriveStrings(DWORD, LPSTR) kernel32 ;
                   from "GetLogicalDriveStringsA"

   extern HMODULE     LoadLibrary( LPCSTR ) kernel32 ;
                   from "LoadLibraryA"
   extern HMODULE     LoadLibraryEx(LPCSTR, HANDLE, DWORD) kernel32 ;
                   from "LoadLibraryA"
   extern DWORD       GetModuleFileName(HMODULE, LPSTR, DWORD) kernel32 ;
                   from "GetModuleFileNameA"
   extern HMODULE     GetModuleHandle( LPCSTR ) kernel32 ;
                   from "GetModuleHandleA"
   extern BOOL        CreateProcess(LPCSTR, LPSTR, LPSTRUCTURE, LPSTRUCTURE, ;
                   BOOL, DWORD, LPVOID, LPCSTR, LPSTRUCTURE, LPSTRUCTURE) ;
                   kernel32 ;
                   from "CreateProcessA"

   extern BOOL        SetProcessShutdownParameters(DWORD, DWORD) kernel32
   extern BOOL        GetProcessShutdownParameters(LPDWORD, LPDWORD) kernel32
   extern DWORD       GetProcessVersion( DWORD ) kernel32

   extern VOID        FatalAppExit(UINT, LPCSTR) kernel32 ;
                   from "FatalAppExitA"
   extern VOID        GetStartupInfo( LPSTRUCTURE) kernel32 ;
                   from "GetStartupInfoA"
   extern LPSTR       GetCommandLine( VOID ) kernel32 ;
                   from "GetCommandLineA"
   extern DWORD       GetEnvironmentVariable(LPCSTR, LPSTR, DWORD) kernel32 ;
                   from "GetEnvironmentVariableA"
   extern BOOL        SetEnvironmentVariable(LPCSTR, LPCSTR) kernel32 ;
                   from "SetEnvironmentVariableA"

   extern DWORD       ExpandEnvironmentStrings(LPCSTR, LPSTR, DWORD) kernel32 ;
                   from "ExpandEnvironmentStringsA"

   extern VOID        OutputDebugString( LPCSTR ) kernel32 ;
                   from "OutputDebugStringA"
   extern HRSRC       FindResource(HMODULE, LPCSTR, LPCSTR) kernel32 ;
                   from "FindResourceA"
   extern HRSRC       FindResourceEx(HMODULE, LPCSTR, LPCSTR, WORD) kernel32 ;
                   from "FindResourceExA"

   extern BOOL        EnumResourceTypes(HMODULE, FARPROC, LONG) kernel32 ;
                   from "EnumResourceTypesA"
   extern BOOL        EnumResourceNames(HMODULE, PCSTR, FARPROC, LONG) kernel32 ;
                   from "EnumResourceNamesA"
   extern BOOL        EnumResourceLanguages(HMODULE, LPCSTR, LPCSTR, FARPROC, ;
                   LONG) kernel32 ;
                   from "EnumResourceLanguagesA"

   extern HANDLE      BeginUpdateResource(LPCSTR, BOOL) kernel32 ;
                   from "BeginUpdateResourceA"
   extern BOOL        UpdateResource(HANDLE, LPCSTR, LPCSTR, WORD, LPVOID, ;
                   DWORD) kernel32 ;
                   from "UpdateResourceA"
   extern BOOL        EndUpdateResource(HANDLE, BOOL) kernel32 ;
                   from "EndUpdateResourceA"

   extern ATOM        GlobalAddAtom( LPCSTR ) kernel32 ;
                   from "GlobalAddAtomA"
   extern ATOM        GlobalFindAtom( LPCSTR ) kernel32 ;
                   from "GlobalFindAtomA"
   extern UINT        GlobalGetAtomName(ATOM, LPSTR, CINT) kernel32 ;
                   from "GlobalGetAtomNameA"
   extern ATOM        AddAtom( LPCSTR ) kernel32 ;
                   from "AddAtomA"
   extern ATOM        FindAtom( LPCSTR ) kernel32 ;
                   from "FindAtomA"
   extern UINT        GetAtomName(ATOM, LPSTR, CINT) kernel32 ;
                   from "GetAtomNameA"

   extern UINT        GetDriveType( LPCSTR ) kernel32 ;
                   from "GetDriveTypeA"

   extern UINT        GetSystemDirectory(LPSTR, UINT) kernel32 ;
                   from "GetSystemDirectoryA"
   extern DWORD       GetTempPath(DWORD, LPSTR) kernel32 ;
                   from "GetTempPathA"
   extern UINT        GetTempFileName(LPCSTR, LPCSTR, UINT, LPSTR) kernel32 ;
                   from "GetTempFileNameA"
   extern UINT        GetWindowsDirectory(LPSTR, UINT) kernel32 ;
                   from "GetWindowsDirectoryA"
   extern BOOL        SetCurrentDirectory( LPCSTR ) kernel32 ;
                   from "SetCurrentDirectoryA"
   extern DWORD       GetCurrentDirectory(DWORD, LPSTR) kernel32 ;
                   from "GetCurrentDirectoryA"
   extern BOOL        GetDiskFreeSpace(LPCSTR, LPDWORD, LPDWORD, LPDWORD, ;
                   LPDWORD) kernel32 ;
                   from "GetDiskFreeSpaceA"
   extern BOOL        CreateDirectory(LPCSTR, LPSTRUCTURE) kernel32 ;
                   from "CreateDirectoryA"
   extern BOOL        CreateDirectoryEx(LPCSTR, LPCSTR, LPSTRUCTURE) kernel32 ;
                   from "CreateDirectoryExA"
   extern BOOL        RemoveDirectory( LPCSTR ) kernel32 ;
                   from "RemoveDirectoryA"
   extern DWORD       GetFullPathName(LPCSTR, DWORD, LPSTR, LPSTR) kernel32 ;
                   from "GetFullPathNameA"

   extern BOOL        DefineDosDevice(DWORD, LPCSTR, LPCSTR) kernel32 ;
                   from "DefineDosDeviceA"
   extern DWORD       QueryDosDevice(LPCSTR, LPSTR, DWORD) kernel32 ;
                   from "QueryDosDeviceA"

   extern HANDLE      CreateFile(LPCSTR, DWORD, DWORD, LPSTRUCTURE, DWORD, ;
                   DWORD, HANDLE) kernel32 ;
                   from "CreateFileA"
   extern BOOL        SetFileAttributes(LPCSTR, DWORD) kernel32 ;
                   from "SetFileAttributesA"
   extern DWORD       GetFileAttributes( LPCSTR ) kernel32 ;
                   from "GetFileAttributesA"

   extern DWORD       GetCompressedFileSize(LPCSTR, LPDWORD) kernel32 ;
                   from "GetCompressedFileSizeA"

   extern BOOL        DeleteFile( LPCSTR ) kernel32 ;
                   from "DeleteFileA"
   extern HANDLE      FindFirstFile(LPCSTR, LPSTRUCTURE) kernel32 ;
                   from "FindFirstFileA"
   extern BOOL        FindNextFile(HANDLE, LPSTRUCTURE) kernel32 ;
                   from "FindNextFileA"
   extern DWORD       SearchPath(LPCSTR, LPCSTR, LPCSTR, DWORD, LPSTR, ;
                   CPTR) kernel32 ;
                   from "SearchPathA"
   extern BOOL        CopyFile(LPCSTR, LPCSTR, BOOL) kernel32 ;
                   from "CopyFileA"
   extern BOOL        MoveFile(LPCSTR, LPCSTR) kernel32 ;
                   from "MoveFileA"
   extern BOOL        MoveFileEx(LPCSTR, LPCSTR, DWORD) kernel32 ;
                   from "MoveFileExA"

   extern HANDLE      CreateMailslot(LPCSTR, DWORD, DWORD, ;
                   LPSTRUCTURE) kernel32 ;
                   from "CreateMailslotA"
   extern BOOL        GetMailslotInfo(HANDLE, LPDWORD, LPDWORD, LPDWORD, ;
                   LPDWORD) kernel32
   extern BOOL        SetMailslotInfo(HANDLE, DWORD) kernel32

   extern BOOL        SetVolumeLabel(LPCSTR, LPCSTR) kernel32 ;
                   from "SetVolumeLabelA"

   extern VOID        SetFileApisToOEM( VOID ) kernel32
   extern VOID        SetFileApisToANSI( VOID ) kernel32
   extern BOOL        AreFileApisANSI( VOID ) kernel32

   extern BOOL        GetVolumeInformation(LPCSTR, LPSTR, DWORD, LPDWORD, ;
                   LPDWORD, LPDWORD, LPSTR, DWORD) kernel32 ;
                   from "GetVolumeInformationA"

   extern HANDLE      FindFirstChangeNotification(LPCSTR, BOOL, ;
                   DWORD) kernel32 ;
                   from "FindFirstChangeNotificationA"
   extern BOOL        FindNextChangeNotification( HANDLE ) kernel32
   extern BOOL        FindCloseChangeNotification( HANDLE ) kernel32
   extern BOOL        VirtualLock(LPVOID, DWORD) kernel32
   extern BOOL        VirtualUnlock(LPVOID, DWORD) kernel32

   extern CLONG       MapViewOfFileEx(HANDLE, DWORD, DWORD, DWORD, ;
                   DWORD, LPVOID) kernel32

   extern BOOL        SetPriorityClass(HANDLE, DWORD) kernel32
   extern DWORD       GetPriorityClass( HANDLE ) kernel32

   extern BOOL        IsBadReadPtr(LPVOID, UINT) kernel32
   extern BOOL        IsBadWritePtr(LPVOID, UINT) kernel32
   extern BOOL        IsBadHugeReadPtr(LPVOID, UINT) kernel32
   extern BOOL        IsBadHugeWritePtr(LPVOID, UINT) kernel32
   extern BOOL        IsBadCodePtr( FARPROC ) kernel32
   extern BOOL        IsBadStringPtr(LPCSTR, UINT) kernel32 ;
                      from "IsBadStringPtrA"


   extern BOOL        BuildCommDCB(LPCSTR, LPSTRUCTURE) kernel32 ;
                      from "BuildCommDCBA"
   extern BOOL        BuildCommDCBAndTimeouts(LPCSTR, LPSTRUCTURE, ;
                      LPSTRUCTURE) kernel32 ;
                      from "BuildCommDCBAndTimeoutsA"
   extern BOOL        CommConfigDialog(LPCSTR, HWND, LPSTRUCTURE) kernel32 ;
                      from "CommConfigDialogA"

   extern BOOL        GetDefaultCommConfig(LPCSTR, LPSTRUCTURE, ;
                      LPDWORD) kernel32 ;
                      from "GetDefaultCommConfigA"

   extern BOOL        SetDefaultCommConfig(LPCSTR, LPSTRUCTURE, ;
                      DWORD) kernel32 ;
                      from "SetDefaultCommConfigA"
   extern BOOL        GetComputerName(LPSTR, LPDWORD) kernel32 ;
                      from "GetComputerNameA"
   extern BOOL        SetComputerName( LPCSTR ) kernel32 ;
                      from "SetComputerNameA"

   //
   // Performance counter API's
   //
   extern BOOL        QueryPerformanceCounter( LPSTRUCTURE ) kernel32
   extern BOOL        QueryPerformanceFrequency( LPSTRUCTURE ) kernel32

   extern BOOL        GetVersionEx( LPSTRUCTURE ) kernel32 ;
                   from "GetVersionExA"

   extern BOOL        GetSystemPowerStatus( LPSTRUCTURE ) kernel32
   extern BOOL        SetSystemPowerState( BOOL, BOOL ) kernel32
return null

function ExternIniFile
   extern UINT        GetProfileInt(LPCSTR, LPCSTR, CINT) kernel32 ;
                      from "GetProfileIntA"
   extern DWORD       GetProfileString(LPCSTR, LPCSTR, LPCSTR, LPSTR, ;
                   DWORD) kernel32 ;
                   from "GetProfileStringA"
   extern BOOL        WriteProfileString(LPCSTR, LPCSTR, LPCSTR) kernel32 ;
                   from "WriteProfileStringA"
   extern DWORD       GetProfileSection(LPCSTR, LPSTR, DWORD) kernel32 ;
                   from "GetProfileSectionA"
   extern BOOL        WriteProfileSection(LPCSTR, LPCSTR) kernel32 ;
                   from "WriteProfileSectionA"

   extern UINT        GetPrivateProfileInt(LPCSTR, LPCSTR, CINT, LPCSTR) kernel32 ;
                   from "GetPrivateProfileIntA"
   extern DWORD       GetPrivateProfileString(LPCSTR, LPCSTR, LPCSTR, LPSTR, ;
                   DWORD, LPCSTR) kernel32 ;
                   from "GetPrivateProfileStringA"
   extern BOOL        WritePrivateProfileString(LPCSTR, LPCSTR, LPCSTR, ;
                   LPCSTR) kernel32 ;
                   from "WritePrivateProfileStringA"
   extern DWORD       GetPrivateProfileSection(LPCSTR, LPSTR, DWORD, ;
                   LPCSTR) kernel32 ;
                   from "GetPrivateProfileSectionA"
   extern BOOL        WritePrivateProfileSection(LPCSTR, LPCSTR, ;
                   LPCSTR) kernel32 ;
                   from "WritePrivateProfileSectionA"
   extern DWORD       GetPrivateProfileSectionNames(LPSTR, DWORD, ;
                   LPCSTR) kernel32 ;
                   from "GetPrivateProfileSectionNamesA"
   extern BOOL        GetPrivateProfileStruct(LPCSTR, LPCSTR, LPVOID, UINT, ;
                   LPCSTR) kernel32 ;
                   from "GetPrivateProfileStructA"
   extern BOOL        WritePrivateProfileStruct(LPCSTR, LPCSTR, LPVOID, UINT, ;
                   LPCSTR) kernel32 ;
                   from "WritePrivateProfileStructA"
return null

function ExternADVAPI
   #define PSID   PVOID
   #define LPPSID PVOID

   extern BOOL        IsTextUnicode(LPVOID, CINT, LPINT) advapi32

   //
   // Event logging APIs
   //

   extern BOOL        ClearEventLog(HANDLE, LPCSTR) advapi32 ;
                   from "ClearEventLogA"
   extern BOOL        BackupEventLog(HANDLE, LPCSTR) advapi32 ;
                   from "BackupEventLogA"
   extern BOOL        CloseEventLog( HANDLE ) advapi32
   extern BOOL        DeregisterEventSource( HANDLE ) advapi32
   extern BOOL        NotifyChangeEventLog(HANDLE, HANDLE) advapi32
   extern BOOL        GetNumberOfEventLogRecords(HANDLE, PDWORD) advapi32
   extern BOOL        GetOldestEventLogRecord(HANDLE, PDWORD) advapi32
   extern HANDLE      OpenEventLog(LPCSTR, LPCSTR) advapi32 ;
                   from "OpenEventLogA"
   extern HANDLE      RegisterEventSource(LPCSTR, LPCSTR) advapi32 ;
                   from "RegisterEventSourceA"
   extern HANDLE      OpenBackupEventLog(LPCSTR, LPCSTR) advapi32 ;
                   from "OpenBackupEventLogA"
   extern BOOL        ReadEventLog(HANDLE, DWORD, DWORD, LPVOID, DWORD, ;
                   DWORD, DWORD) advapi32 ;
                   from "ReadEventLogA"
   extern BOOL        ReportEvent(HANDLE, WORD, WORD, DWORD, PSID, WORD, ;
                   DWORD, CPTR, LPVOID) advapi32 ;
                   from "ReportEventA"
   //
   // Security APIs
   //

   extern BOOL        DuplicateToken(HANDLE, ENUM, PHANDLE) advapi32
   extern BOOL        GetKernelObjectSecurity(HANDLE, SECURITY_INFORMATION, ;
                   LPSTRUCTURE, DWORD, LPDWORD) advapi32
   extern BOOL        ImpersonateNamedPipeClient( HANDLE ) advapi32
   extern BOOL        ImpersonateSelf( ENUM ) advapi32
   extern BOOL        RevertToSelf ( VOID ) advapi32
   extern BOOL        SetThreadToken(PHANDLE, HANDLE) advapi32
   extern BOOL        AccessCheck(LPSTRUCTURE, HANDLE, DWORD, PSTRUCTURE, ;
                   PSTRUCTURE, LPDWORD, LPDWORD, LPBOOL) advapi32
   extern BOOL        OpenProcessToken(HANDLE, DWORD, PHANDLE) advapi32
   extern BOOL        OpenThreadToken(HANDLE, DWORD, BOOL, PHANDLE) advapi32
   extern BOOL        GetTokenInformation(HANDLE, ENUM, LPVOID, DWORD, ;
                   PDWORD) advapi32
   extern BOOL        SetTokenInformation(HANDLE, ENUM, LPVOID, DWORD) advapi32
   extern BOOL        AdjustTokenPrivileges(HANDLE, BOOL, LPSTRUCTURE, DWORD, ;
                   LPSTRUCTURE, PDWORD) advapi32
   extern BOOL        AdjustTokenGroups(HANDLE, BOOL, LPSTRUCTURE, DWORD, ;
                   LPSTRUCTURE, PDWORD) advapi32
   extern BOOL        PrivilegeCheck(HANDLE, LPSTRUCTURE, LPBOOL) advapi32
   extern BOOL        AccessCheckAndAuditAlarm(LPCSTR, LPVOID, LPSTR, LPSTR, ;
                   LPSTRUCTURE, DWORD, LPSTRUCTURE, BOOL, LPDWORD, LPBOOL, ;
                   LPBOOL) advapi32 ;
                   from "AccessCheckAndAuditAlarmA"
   extern BOOL        ObjectOpenAuditAlarm(LPCSTR, LPVOID, LPSTR, LPSTR, ;
                   LPSTRUCTURE, HANDLE, DWORD, DWORD, LPSTRUCTURE, BOOL, ;
                   BOOL, LPBOOL) advapi32 ;
                   from "ObjectOpenAuditAlarmA"
   extern BOOL        ObjectPrivilegeAuditAlarm(LPCSTR, LPVOID, HANDLE, ;
                   DWORD, LPSTRUCTURE, BOOL) advapi32 ;
                   from "ObjectPrivilegeAuditAlarmA"
   extern BOOL        ObjectCloseAuditAlarm(LPCSTR, LPVOID, BOOL) advapi32 ;
                   from "ObjectCloseAuditAlarmA"
   extern BOOL        PrivilegedServiceAuditAlarm(LPCSTR, LPCSTR, HANDLE, ;
                   LPSTRUCTURE, BOOL) advapi32 ;
                   from "PrivilegedServiceAuditAlarmA"
   extern BOOL        IsValidSid( PSID ) advapi32
   extern BOOL        EqualSid (PSID, PSID) advapi32
   extern BOOL        EqualPrefixSid(PSID, PSID) advapi32
   extern DWORD       GetSidLengthRequired( UCHAR ) advapi32
   extern BOOL        AllocateAndInitializeSid(LPSTRUCTURE, BYTE, DWORD, ;
                   DWORD, DWORD, DWORD, DWORD, DWORD, DWORD, DWORD, ;
                   LPPSID) advapi32
   extern CSTRING     FreeSid( PSID ) advapi32
   extern BOOL        InitializeSid(PSID, LPSTRUCTURE, BYTE) advapi32
   extern DWORD       GetSidIdentifierAuthority( PSID ) advapi32
   extern PDWORD      GetSidSubAuthority(PSID, DWORD) advapi32
   extern CSTRING     GetSidSubAuthorityCount( PSID ) advapi32
   extern DWORD       GetLengthSid ( PSID ) advapi32
   extern BOOL        CopySid(DWORD, PSID, PSID) advapi32
   extern BOOL        AreAllAccessesGranted(DWORD, DWORD) advapi32
   extern BOOL        AreAnyAccessesGranted(DWORD, DWORD) advapi32
   extern VOID        MapGenericMask(PDWORD, LPSTRUCTURE) advapi32
   extern BOOL        IsValidAcl( PSTRUCTURE ) advapi32
   extern BOOL        InitializeAcl(PSTRUCTURE, DWORD, DWORD) advapi32
   extern BOOL        GetAclInformation(PSTRUCTURE, LPVOID, DWORD, ;
                   ENUM) advapi32
   extern BOOL        SetAclInformation(PSTRUCTURE, LPVOID, DWORD, ;
                   ENUM) advapi32
   extern BOOL        AddAce(PSTRUCTURE, DWORD, DWORD, LPVOID, DWORD) advapi32
   extern BOOL        DeleteAce(PSTRUCTURE, DWORD) advapi32
   extern BOOL        GetAce(PSTRUCTURE, DWORD, LPVOID) advapi32
   extern BOOL        AddAccessAllowedAce(PSTRUCTURE, DWORD, DWORD, ;
                   PSID) advapi32
   extern BOOL        AddAccessDeniedAce(PSTRUCTURE, DWORD, DWORD, ;
                   PSID) advapi32
   extern BOOL        AddAuditAccessAce(PSTRUCTURE, DWORD, DWORD, PSID, BOOL, ;
                   BOOL) advapi32
   extern BOOL        FindFirstFreeAce(PSTRUCTURE, LPVOID) advapi32
   extern BOOL        InitializeSecurityDescriptor(LPSTRUCTURE, DWORD) advapi32
   extern BOOL        IsValidSecurityDescriptor(LPSTRUCTURE) advapi32
   extern DWORD       GetSecurityDescriptorLength(LPSTRUCTURE) advapi32
   extern BOOL        GetSecurityDescriptorControl(LPSTRUCTURE, LPSTRUCTURE, ;
                   LPDWORD) advapi32
   extern BOOL        SetSecurityDescriptorDacl(LPSTRUCTURE, BOOL, PSTRUCTURE, ;
                   BOOL) advapi32
   extern BOOL        GetSecurityDescriptorDacl(LPSTRUCTURE, LPBOOL, ;
                   CPTR, LPBOOL) advapi32
   extern BOOL        SetSecurityDescriptorSacl(LPSTRUCTURE, BOOL, PSTRUCTURE, ;
                   BOOL) advapi32
   extern BOOL        GetSecurityDescriptorSacl(LPSTRUCTURE, LPBOOL, ;
                   CPTR, LPBOOL) advapi32
   extern BOOL        SetSecurityDescriptorOwner(LPSTRUCTURE, PSID, ;
                   BOOL) advapi32
   extern BOOL        GetSecurityDescriptorOwner(LPSTRUCTURE, LPPSID, ;
                   LPBOOL) advapi32
   extern BOOL        SetSecurityDescriptorGroup(LPSTRUCTURE, PSID, ;
                   BOOL) advapi32
   extern BOOL        GetSecurityDescriptorGroup(LPSTRUCTURE, LPPSID, ;
                   LPBOOL) advapi32
   extern BOOL        CreatePrivateObjectSecurity(LPSTRUCTURE, LPSTRUCTURE, ;
                   CPTR, BOOL, HANDLE, LPSTRUCTURE) advapi32
   extern BOOL        SetPrivateObjectSecurity(SECURITY_INFORMATION, ;
                   LPSTRUCTURE, CPTR, LPSTRUCTURE, HANDLE) advapi32
   extern BOOL        GetPrivateObjectSecurity(LPSTRUCTURE, ;
                   SECURITY_INFORMATION, LPSTRUCTURE, ;
                   DWORD, PDWORD) advapi32
   extern BOOL        DestroyPrivateObjectSecurity(LPSTRUCTURE) advapi32
   extern BOOL        MakeSelfRelativeSD(LPSTRUCTURE, LPSTRUCTURE, ;
                   LPDWORD) advapi32
   extern BOOL        MakeAbsoluteSD(LPSTRUCTURE, LPSTRUCTURE, LPDWORD, ;
                   PSTRUCTURE, LPDWORD, PSTRUCTURE, LPDWORD, PSID, ;
                   LPDWORD, PSID, LPDWORD) advapi32
   extern BOOL        SetFileSecurity(LPCSTR, SECURITY_INFORMATION, ;
                   LPSTRUCTURE) advapi32 ;
                   from "SetFileSecurityA"
   extern BOOL        GetFileSecurity(LPCSTR, SECURITY_INFORMATION, ;
                   LPSTRUCTURE, DWORD, LPDWORD) advapi32 ;
                   from "GetFileSecurityA"
   extern BOOL        SetKernelObjectSecurity(HANDLE, SECURITY_INFORMATION, ;
                   LPSTRUCTURE) advapi32

   extern BOOL        LookupAccountSid(LPCSTR, PSID, LPSTR, LPDWORD, ;
                   LPSTR, LPDWORD, LPSTRUCTURE) advapi32 ;
                   from "LookupAccountSidA"
   extern BOOL        LookupAccountName(LPCSTR, LPCSTR, PSID, LPDWORD, LPSTR, ;
                   LPDWORD, LPSTRUCTURE) advapi32 ;
                   from "LookupAccountNameA"
   extern BOOL        LookupPrivilegeValue(LPCSTR, LPCSTR, ;
                   LPSTRUCTURE) advapi32 ;
                   from "LookupPrivilegeValueA"
   extern BOOL        LookupPrivilegeName(LPCSTR, LPSTRUCTURE, LPSTR, ;
                   LPDWORD) advapi32 ;
                   from "LookupPrivilegeNameA"
   extern BOOL        LookupPrivilegeDisplayName(LPCSTR, LPCSTR, LPSTR, ;
                   LPDWORD, LPDWORD) advapi32 ;
                   from "LookupPrivilegeDisplayNameA"
   extern BOOL        AllocateLocallyUniqueId( LPSTRUCTURE ) advapi32


   extern BOOL        GetUserName(LPSTR, LPDWORD) advapi32 ;
                   from "GetUserNameA"

   //
   // Logon Support APIs
   //
   extern BOOL        LogonUser(LPSTR, LPSTR, LPSTR, DWORD, DWORD, ;
                   PHANDLE) advapi32 ;
                   from "LogonUserA"
   extern BOOL        ImpersonateLoggedOnUser( HANDLE ) advapi32
   extern BOOL        CreateProcessAsUser(HANDLE, LPCSTR, LPSTR, ;
                   LPSTRUCTURE, LPSTRUCTURE, BOOL, DWORD, LPVOID, ;
                   LPCSTR, LPSTRUCTURE) advapi32 ;
                   from "CreateProcessAsUserA"
return null

function ExternGDI
   //------------------------------------------------------------------     
   //
   // Adapted from wingdi.h 
   // GDI procedure declarations, constant definitions and macros
   // 
   //------------------------------------------------------------------      

   extern CINT        AddFontResource(LPCSTR) gdi32 ;
                   from "AddFontResourceA"

   extern BOOL        AnimatePalette(HPALETTE, UINT, UINT, LPSTRUCTURE) gdi32
   extern BOOL        Arc(HDC, CINT, CINT, CINT, CINT, CINT, CINT, ;
                   CINT, CINT) gdi32
   extern BOOL        BitBlt(HDC, CINT, CINT, CINT, CINT, HDC, CINT, ;
                   CINT, DWORD) gdi32
   extern BOOL        CancelDC(HDC) gdi32
   extern BOOL        Chord(HDC, CINT, CINT, CINT, CINT, CINT, CINT, ;
                   CINT, CINT) gdi32
   extern CINT        ChoosePixelFormat(HDC, LPSTRUCTURE) gdi32
   extern HMETAFILE   CloseMetaFile(HDC) gdi32
   extern CINT        CombineRgn(HRGN, HRGN, HRGN, CINT) gdi32
   extern HMETAFILE   CopyMetaFile(HMETAFILE, LPCSTR) gdi32 ;
                   from "CopyMetaFileA"
   extern HBITMAP     CreateBitmap(CINT, CINT, UINT, UINT, CPTR) gdi32
   extern HBITMAP     CreateBitmapIndirect(LPSTRUCTURE) gdi32
   extern HBRUSH      CreateBrushIndirect(LPSTRUCTURE) gdi32
   extern HBITMAP     CreateCompatibleBitmap(HDC, CINT, CINT) gdi32
   extern HBITMAP     CreateDiscardableBitmap(HDC, CINT, CINT) gdi32
   extern HDC         CreateCompatibleDC(HDC) gdi32
   extern HDC         CreateDC(LPCSTR, LPCSTR , LPCSTR , LPSTRUCTURE) gdi32 ;
                   from "CreateDCA"
   extern HBITMAP     CreateDIBitmap(HDC, LPSTRUCTURE, DWORD, LPSTRUCTURE, ;
                   LPSTRUCTURE, UINT) gdi32
   extern HBRUSH      CreateDIBPatternBrush(HGLOBAL, UINT) gdi32
   extern HBRUSH      CreateDIBPatternBrushPt(CPTR, UINT) gdi32
   extern HRGN        CreateEllipticRgn(CINT, CINT, CINT, CINT) gdi32
   extern HRGN        CreateEllipticRgnIndirect(LPSTRUCTURE) gdi32
   extern HFONT       CreateFontIndirect(LPSTRUCTURE) gdi32 ;
                   from "CreateFontIndirectA"
   extern HFONT       CreateFont(CINT, CINT, CINT, CINT, CINT, DWORD, ;
                   DWORD, DWORD, DWORD, DWORD, DWORD, ;
                   DWORD, DWORD, LPCSTR) gdi32 ;
                   from "CreateFontA"

   extern HBRUSH      CreateHatchBrush(CINT, COLORREF) gdi32
   extern HDC         CreateIC(LPCSTR, LPCSTR , LPCSTR , LPSTRUCTURE) gdi32 ;
                   from "CreateICA"
   extern HDC         CreateMetaFile(LPCSTR) gdi32 ;
                   from "CreateMetaFileA"

   extern HPALETTE    CreatePalette(LPSTRUCTURE) gdi32
   extern HPEN        CreatePen(CINT, CINT, COLORREF) gdi32
   extern HPEN        CreatePenIndirect(LPSTRUCTURE) gdi32
   extern HRGN        CreatePolyPolygonRgn(LPSTRUCTURE, PINT, CINT, CINT) gdi32
   extern HBRUSH      CreatePatternBrush(HBITMAP) gdi32
   extern HRGN        CreateRectRgn(CINT, CINT, CINT, CINT) gdi32
   extern HRGN        CreateRectRgnIndirect(LPSTRUCTURE) gdi32
   extern HRGN        CreateRoundRectRgn(CINT, CINT, CINT, CINT, CINT, CINT) gdi32
   extern BOOL        CreateScalableFontResource(DWORD, LPCSTR, LPCSTR, ;
                   LPCSTR) gdi32 ;
                   from "CreateScalableFontResourceA"
   extern HBRUSH      CreateSolidBrush(COLORREF) gdi32

   extern BOOL        DeleteDC(HDC) gdi32
   extern BOOL        DeleteMetaFile(HMETAFILE) gdi32
   extern BOOL        DeleteObject(HGDIOBJ) gdi32
   extern CINT        DescribePixelFormat(HDC, CINT, UINT, LPSTRUCTURE) gdi32

   extern CINT        DeviceCapabilities(LPCSTR, LPCSTR, WORD, ;
                   LPSTR, LPSTRUCTURE) winspool.drv ;
                   from "DeviceCapabilitiesA"

   extern CINT        DrawEscape(HDC, CINT, CINT, LPCSTR) gdi32
   extern BOOL        Ellipse(HDC, CINT, CINT, CINT, CINT) gdi32

   extern CINT        EnumFontFamiliesEx(HDC, LPSTRUCTURE, FARPROC, ;
                   LPARAM, DWORD) gdi32 ;
                   from "EnumFontFamiliesExA"
   extern CINT        EnumFontFamilies(HDC, LPCSTR, FARPROC, LPARAM) gdi32 ;
                   from "EnumFontFamiliesA"
   extern CINT        EnumFonts(HDC, LPCSTR, FARPROC, LPARAM) gdi32 ;
                   from "EnumFontsA"
   extern CINT        EnumObjects(HDC, CINT, FARPROC, LPVOID) gdi32


   extern BOOL        EqualRgn(HRGN, HRGN) gdi32
   extern CINT        Escape(HDC, CINT, CINT, LPCSTR, LPVOID) gdi32
   extern CINT        ExtEscape(HDC, CINT, CINT, LPCSTR, CINT, LPSTR) gdi32
   extern CINT        ExcludeClipRect(HDC, CINT, CINT, CINT, CINT) gdi32
   extern HRGN        ExtCreateRegion(LPSTRUCTURE, DWORD, LPSTRUCTURE) gdi32
   extern BOOL        ExtFloodFill(HDC, CINT, CINT, COLORREF, UINT) gdi32
   extern BOOL        FillRgn(HDC, HRGN, HBRUSH) gdi32
   extern BOOL        FloodFill(HDC, CINT, CINT, COLORREF) gdi32
   extern BOOL        FrameRgn(HDC, HRGN, HBRUSH, CINT, CINT) gdi32
   extern CINT        GetROP2(HDC) gdi32
   extern BOOL        GetAspectRatioFilterEx(HDC, LPSTRUCTURE) gdi32
   extern COLORREF    GetBkColor(HDC) gdi32
   extern CINT        GetBkMode(HDC) gdi32
   extern LONG        GetBitmapBits(HBITMAP, LONG, LPVOID) gdi32
   extern BOOL        GetBitmapDimensionEx(HBITMAP, LPSTRUCTURE) gdi32
   extern UINT        GetBoundsRect(HDC, LPSTRUCTURE, UINT) gdi32

   extern BOOL        GetBrushOrgEx(HDC, LPSTRUCTURE) gdi32

   extern BOOL        GetCharWidth(HDC, UINT, UINT, LPINT) gdi32 ;
                   from "GetCharWidthA"
   extern BOOL        GetCharWidth32(HDC, UINT, UINT, LPINT) gdi32 ;
                   from "GetCharWidth32A"
   extern BOOL        GetCharWidthFloat(HDC, UINT, UINT, PFLOAT) gdi32 ;
                   from "GetCharWidthFloatA"

   extern BOOL        GetCharABCWidths(HDC, UINT, UINT, LPSTRUCTURE) gdi32 ;
                   from "GetCharABCWidthsA"
   extern BOOL        GetCharABCWidthsFloat(HDC, UINT, UINT, LPSTRUCTURE) gdi32 ;
                   from "GetCharABCWidthsFloatA"

   extern CINT        GetClipBox(HDC, LPRECT) gdi32
   extern CINT        GetClipRgn(HDC, HRGN) gdi32
   extern CINT        GetMetaRgn(HDC, HRGN) gdi32
   extern HGDIOBJ     GetCurrentObject(HDC, UINT) gdi32
   extern BOOL        GetCurrentPositionEx(HDC, LPSTRUCTURE) gdi32
   extern CINT        GetDeviceCaps(HDC, CINT) gdi32
   extern CINT        GetDIBits(HDC, HBITMAP, UINT, UINT, LPVOID, LPSTRUCTURE, UINT) gdi32
   extern DWORD       GetFontData(HDC, DWORD, DWORD, LPVOID, DWORD) gdi32
   extern DWORD       GetGlyphOutlineA(HDC, UINT, UINT, LPSTRUCTURE, DWORD, LPVOID, LPSTRUCTURE) gdi32
   extern CINT        GetGraphicsMode(HDC) gdi32
   extern CINT        GetMapMode(HDC) gdi32
   extern UINT        GetMetaFileBitsEx(HMETAFILE, UINT, LPVOID) gdi32
   extern HMETAFILE   GetMetaFile(LPCSTR) gdi32 ;
                   from "GetMetaFileA"

   extern COLORREF    GetNearestColor(HDC, COLORREF) gdi32
   extern UINT        GetNearestPaletteIndex(HPALETTE, COLORREF) gdi32
   extern DWORD       GetObjectType(HGDIOBJ) gdi32

   extern UINT        GetOutlineTextMetrics(HDC, UINT, LPSTRUCTURE) gdi32 ;
                   from "GetOutlineTextMetricsA"

   extern UINT        GetPaletteEntries(HPALETTE, UINT, UINT, LPSTRUCTURE) gdi32
   extern COLORREF    GetPixel(HDC, CINT, CINT) gdi32
   extern CINT        GetPixelFormat(HDC) gdi32
   extern CINT        GetPolyFillMode(HDC) gdi32
   extern BOOL        GetRasterizerCaps(LPSTRUCTURE, UINT) gdi32
   extern DWORD       GetRegionData(HRGN, DWORD, LPSTRUCTURE) gdi32
   extern CINT        GetRgnBox(HRGN, LPSTRUCTURE) gdi32
   extern HGDIOBJ     GetStockObject(CINT) gdi32
   extern CINT        GetStretchBltMode(HDC) gdi32
   extern UINT        GetSystemPaletteEntries(HDC, UINT, UINT, LPSTRUCTURE) gdi32
   extern UINT        GetSystemPaletteUse(HDC) gdi32
   extern CINT        GetTextCharacterExtra(HDC) gdi32
   extern UINT        GetTextAlign(HDC) gdi32
   extern COLORREF    GetTextColor(HDC) gdi32

   extern BOOL        GetTextExtentPoint(HDC, LPCSTR, CINT, LPSTRUCTURE) gdi32 ;
                   from "GetTextExtentPointA"

   extern BOOL        GetTextExtentPoint32(HDC, LPCSTR, CINT, LPSTRUCTURE) gdi32 ;
                   from "GetTextExtentPoint32A"

   extern BOOL        GetTextExtentExPoint(HDC, LPCSTR, CINT, CINT, LPINT, ;
                   LPINT, LPSTRUCTURE) gdi32 ;
                   from "GetTextExtentExPointA"

   extern CINT        GetTextCharset(HDC) gdi32
   extern CINT        GetTextCharsetInfo(HDC, LPSTRUCTURE, DWORD) gdi32
   extern BOOL        TranslateCharsetInfo( LPDWORD, LPSTRUCTURE, DWORD) gdi32
   extern DWORD       GetFontLanguageInfo( HDC ) gdi32
   extern DWORD       GetCharacterPlacement(HDC, LPCSTR, CINT, CINT, ;
                   LPSTRUCTURE, DWORD) gdi32 ;
                   from "GetCharacterPlacementA"

   extern BOOL        GetViewportExtEx(HDC, LPSTRUCTURE) gdi32
   extern BOOL        GetViewportOrgEx(HDC, LPSTRUCTURE) gdi32
   extern BOOL        GetWindowExtEx(HDC, LPSTRUCTURE) gdi32
   extern BOOL        GetWindowOrgEx(HDC, LPSTRUCTURE) gdi32

   extern CINT        IntersectClipRect(HDC, CINT, CINT, CINT, CINT) gdi32
   extern BOOL        InvertRgn(HDC, HRGN) gdi32
   extern BOOL        LineDDA(CINT, CINT, CINT, CINT, FARPROC, LPARAM) gdi32
   extern BOOL        LineTo(HDC, CINT, CINT) gdi32
   extern BOOL        MaskBlt(HDC, CINT, CINT, CINT, CINT, ;
                   HDC, CINT, CINT, HBITMAP, CINT, CINT, DWORD) gdi32
   extern BOOL        PlgBlt(HDC, LPSTRUCTURE, HDC, CINT, CINT, CINT, ;
                   CINT, HBITMAP, CINT, CINT) gdi32

   extern CINT        OffsetClipRgn(HDC, CINT, CINT) gdi32
   extern CINT        OffsetRgn(HRGN, CINT, CINT) gdi32
   extern BOOL        PatBlt(HDC, CINT, CINT, CINT, CINT, DWORD) gdi32
   extern BOOL        Pie(HDC, CINT, CINT, CINT, CINT, CINT, CINT, ;
                   CINT, CINT) gdi32
   extern BOOL        PlayMetaFile(HDC, HMETAFILE) gdi32
   extern BOOL        PaintRgn(HDC, HRGN) gdi32
   extern BOOL        PolyPolygon(HDC, LPSTRUCTURE, PINT, CINT) gdi32
   extern BOOL        PtInRegion(HRGN, CINT, CINT) gdi32
   extern BOOL        PtVisible(HDC, CINT, CINT) gdi32
   extern BOOL        RectInRegion(HRGN, LPSTRUCTURE) gdi32
   extern BOOL        RectVisible(HDC, LPSTRUCTURE) gdi32
   extern BOOL        Rectangle(HDC, CINT, CINT, CINT, CINT) gdi32
   extern BOOL        RestoreDC(HDC, CINT) gdi32
   extern HDC         ResetDC(HDC, LPSTRUCTURE) gdi32 ;
                   from "ResetDCA"

   extern UINT        RealizePalette(HDC) gdi32
   extern BOOL        RemoveFontResource(LPCSTR) gdi32 ;
                   from "RemoveFontResourceA"
   extern BOOL        RoundRect(HDC, CINT, CINT, CINT, CINT, CINT, CINT) gdi32
   extern BOOL        ResizePalette(HPALETTE, UINT) gdi32

   extern CINT        SaveDC(HDC) gdi32
   extern CINT        SelectClipRgn(HDC, HRGN) gdi32
   extern CINT        ExtSelectClipRgn(HDC, HRGN, CINT) gdi32
   extern CINT        SetMetaRgn(HDC) gdi32
   extern HGDIOBJ     SelectObject(HDC, HGDIOBJ) gdi32
   extern HPALETTE    SelectPalette(HDC, HPALETTE, BOOL) gdi32
   extern COLORREF    SetBkColor(HDC, COLORREF) gdi32
   extern CINT        SetBkMode(HDC, CINT) gdi32
   extern LONG        SetBitmapBits(HBITMAP, DWORD, CPTR) gdi32

   extern UINT        SetBoundsRect(HDC, LPSTRUCTURE, UINT) gdi32
   extern CINT        SetDIBits(HDC, HBITMAP, UINT, UINT, LPSTRUCTURE, ;
                   LPSTRUCTURE, UINT) gdi32
   extern CINT        SetDIBitsToDevice(HDC, CINT, CINT, DWORD, DWORD, CINT, ;
                   CINT, UINT, UINT, CPTR, LPSTRUCTURE, UINT) gdi32
   extern DWORD       SetMapperFlags(HDC, DWORD) gdi32
   extern CINT        SetGraphicsMode(HDC, CINT) gdi32
   extern CINT        SetMapMode(HDC, CINT) gdi32
   extern HMETAFILE   SetMetaFileBitsEx(UINT, PBYTE) gdi32
   extern UINT        SetPaletteEntries(HPALETTE, UINT, UINT, LPSTRUCTURE) gdi32
   extern COLORREF    SetPixel(HDC, CINT, CINT, COLORREF) gdi32
   extern BOOL        SetPixelV(HDC, CINT, CINT, COLORREF) gdi32
   extern BOOL        SetPixelFormat(HDC, CINT, LPSTRUCTURE) gdi32
   extern CINT        SetPolyFillMode(HDC, CINT) gdi32
   extern BOOL        StretchBlt(HDC, CINT, CINT, CINT, CINT, HDC, CINT, ;
                   CINT, CINT, CINT, DWORD) gdi32
   extern BOOL        SetRectRgn(HRGN, CINT, CINT, CINT, CINT) gdi32
   extern CINT        StretchDIBits(HDC, CINT, CINT, CINT, CINT, CINT, ;
                   CINT, CINT, CINT, LPSTRUCTURE, CPTR, LPSTRUCTURE, ;
                   UINT, DWORD) gdi32
   extern CINT        SetROP2(HDC, CINT) gdi32
   extern CINT        SetStretchBltMode(HDC, CINT) gdi32
   extern UINT        SetSystemPaletteUse(HDC, UINT) gdi32
   extern CINT        SetTextCharacterExtra(HDC, CINT) gdi32
   extern COLORREF    SetTextColor(HDC, COLORREF) gdi32
   extern UINT        SetTextAlign(HDC, UINT) gdi32
   extern BOOL        SetTextJustification(HDC, CINT, CINT) gdi32
   extern BOOL        UpdateColors(HDC) gdi32

   extern BOOL        PlayMetaFileRecord(HDC, LPSTRUCTURE, LPSTRUCTURE, ;
                   UINT) gdi32
   extern BOOL        EnumMetaFile(HDC, HMETAFILE, FARPROC, LPARAM) gdi32

   // Enhanced Metafile Function Declarations
   extern HENHMETAFILE CloseEnhMetaFile(HDC) gdi32
   extern HENHMETAFILE CopyEnhMetaFile(HENHMETAFILE, LPCSTR) gdi32 ;
                    from "CopyEnhMetaFileA"
   extern HDC         CreateEnhMetaFile(HDC, LPCSTR, LPSTRUCTURE, LPCSTR) gdi32 ;
                   from "CreateEnhMetaFileA"
   extern BOOL        DeleteEnhMetaFile(HENHMETAFILE) gdi32
   extern BOOL        EnumEnhMetaFile(HDC, HENHMETAFILE, FARPROC, LPVOID, ;
                   LPSTRUCTURE) gdi32
   extern HENHMETAFILE  GetEnhMetaFile(LPCSTR) gdi32 ;
                     from "GetEnhMetaFileA"
   extern UINT        GetEnhMetaFileBits(HENHMETAFILE, UINT, LPBYTE) gdi32
   extern UINT        GetEnhMetaFileDescription(HENHMETAFILE, UINT, ;
                   LPSTR ) gdi32 ;
                   from "GetEnhMetaFileDescriptionA"

   extern UINT        GetEnhMetaFileHeader(HENHMETAFILE, UINT, LPSTRUCTURE) gdi32
   extern UINT        GetEnhMetaFilePaletteEntries(HENHMETAFILE, UINT, ;
                   LPSTRUCTURE) gdi32
   extern UINT        GetWinMetaFileBits(HENHMETAFILE, UINT, LPBYTE, ;
                   CINT, HDC) gdi32
   extern BOOL        PlayEnhMetaFile(HDC, HENHMETAFILE, LPSTRUCTURE) gdi32
   extern BOOL        PlayEnhMetaFileRecord(HDC, LPSTRUCTURE, ;
                   LPSTRUCTURE, UINT) gdi32
   extern HENHMETAFILE  SetEnhMetaFileBits(UINT, LPBYTE) gdi32
   extern HENHMETAFILE  SetWinMetaFileBits(UINT, LPBYTE, HDC, LPSTRUCTURE) gdi32
   extern BOOL        GdiComment(HDC, UINT, LPBYTE) gdi32

   extern BOOL        GetTextMetrics(HDC, LPSTRUCTURE) gdi32 ;
                   from "GetTextMetricsA"

   // new GDI

   extern BOOL        AngleArc(HDC, CINT, CINT, DWORD, CFLOAT, CFLOAT) gdi32
   extern BOOL        PolyPolyline(HDC, LPSTRUCTURE, LPDWORD, DWORD) gdi32
   extern BOOL        GetWorldTransform(HDC, LPSTRUCTURE) gdi32
   extern BOOL        SetWorldTransform(HDC, LPSTRUCTURE) gdi32
   extern BOOL        ModifyWorldTransform(HDC, LPSTRUCTURE, DWORD) gdi32
   extern BOOL        CombineTransform(LPSTRUCTURE, LPSTRUCTURE, LPSTRUCTURE) gdi32
   extern HBITMAP     CreateDIBSection(HDC, LPSTRUCTURE, UINT, CPTR, ;
                   HANDLE, DWORD) gdi32
   extern UINT        GetDIBColorTable(HDC, UINT, UINT, LPSTRUCTURE) gdi32
   extern UINT        SetDIBColorTable(HDC, UINT, UINT, LPSTRUCTURE) gdi32

   extern BOOL        SetColorAdjustment(HDC, LPSTRUCTURE) gdi32
   extern BOOL        GetColorAdjustment(HDC, LPSTRUCTURE) gdi32
   extern HPALETTE    CreateHalftonePalette(HDC) gdi32

   extern CINT        StartDoc(HDC, LPSTRUCTURE) gdi32 ;
                   from "StartDocA"
   extern CINT        EndDoc(HDC) gdi32
   extern CINT        StartPage(HDC) gdi32
   extern CINT        EndPage(HDC) gdi32
   extern CINT        AbortDoc(HDC) gdi32
   extern CINT        SetAbortProc(HDC, FARPROC) gdi32

   extern BOOL        AbortPath(HDC) gdi32
   extern BOOL        ArcTo(HDC, CINT, CINT, CINT, CINT, CINT, CINT, ;
                   CINT, CINT) gdi32
   extern BOOL        BeginPath(HDC) gdi32
   extern BOOL        CloseFigure(HDC) gdi32
   extern BOOL        EndPath(HDC) gdi32
   extern BOOL        FillPath(HDC) gdi32
   extern BOOL        FlattenPath(HDC) gdi32
   extern CINT        GetPath(HDC, LPSTRUCTURE, LPBYTE, CINT) gdi32
   extern HRGN        PathToRegion(HDC) gdi32
   extern BOOL        PolyDraw(HDC, LPSTRUCTURE, LPBYTE, CINT) gdi32
   extern BOOL        SelectClipPath(HDC, CINT) gdi32
   extern CINT        SetArcDirection(HDC, CINT) gdi32
   extern BOOL        SetMiterLimit(HDC, CFLOAT, PFLOAT) gdi32
   extern BOOL        StrokeAndFillPath(HDC) gdi32
   extern BOOL        StrokePath(HDC) gdi32
   extern BOOL        WidenPath(HDC) gdi32
   extern HPEN        ExtCreatePen(DWORD, DWORD, LPSTRUCTURE, DWORD, LPDWORD) gdi32
   extern BOOL        GetMiterLimit(HDC, PFLOAT) gdi32
   extern CINT        GetArcDirection(HDC) gdi32

   extern CINT        GetObject(HGDIOBJ, CINT, LPVOID) gdi32 ;
                   from "GetObjectA"
   extern BOOL        MoveToEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        TextOut(HDC, CINT, CINT, LPCSTR, CINT) gdi32 ;
                   from "TextOutA"
   extern BOOL        ExtTextOut(HDC, CINT, CINT, UINT, LPSTRUCTURE, ;
                   LPCSTR, UINT, LPINT) gdi32 ;
                   from "ExtTextOutA"
   extern BOOL        PolyTextOut(HDC, LPSTRUCTURE, CINT) gdi32 ;
                   from "PolyTextOutA"

   extern HRGN        CreatePolygonRgn(LPSTRUCTURE, CINT, CINT) gdi32
   extern BOOL        DPtoLP(HDC, LPSTRUCTURE, CINT) gdi32
   extern BOOL        LPtoDP(HDC, LPSTRUCTURE, CINT) gdi32
   extern BOOL        Polygon(HDC, LPSTRUCTURE, CINT) gdi32
   extern BOOL        Polyline(HDC, LPSTRUCTURE, CINT) gdi32

   extern BOOL        PolyBezier(HDC, LPSTRUCTURE, DWORD) gdi32
   extern BOOL        PolyBezierTo(HDC, LPSTRUCTURE, DWORD) gdi32
   extern BOOL        PolylineTo(HDC, LPSTRUCTURE, DWORD) gdi32

   extern BOOL        SetViewportExtEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        SetViewportOrgEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        SetWindowExtEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        SetWindowOrgEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32

   extern BOOL        OffsetViewportOrgEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        OffsetWindowOrgEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        ScaleViewportExtEx(HDC, CINT, CINT, CINT, CINT, ;
                   LPSTRUCTURE) gdi32
   extern BOOL        ScaleWindowExtEx(HDC, CINT, CINT, CINT, CINT, ;
                   LPSTRUCTURE) gdi32
   extern BOOL        SetBitmapDimensionEx(HBITMAP, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        SetBrushOrgEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32

   extern CINT        GetTextFace(HDC, CINT, LPSTR) gdi32 ;
                   from "GetTextFaceA"

   extern DWORD       GetKerningPairs(HDC, DWORD, LPSTRUCTURE) gdi32 ;
                   from "GetKerningPairsA"

   extern BOOL        GetDCOrgEx(HDC, LPSTRUCTURE) gdi32
   extern BOOL        FixBrushOrgEx(HDC, CINT, CINT, LPSTRUCTURE) gdi32
   extern BOOL        UnrealizeObject(HGDIOBJ) gdi32

   extern BOOL        GdiFlush() gdi32
   extern DWORD       GdiSetBatchLimit(DWORD) gdi32
   extern DWORD       GdiGetBatchLimit() gdi32

   extern CINT        SetICMMode(HDC, CINT) gdi32
   extern BOOL        CheckColorsInGamut(HDC, LPVOID, LPVOID, DWORD) gdi32
   extern HANDLE      GetColorSpace(HDC) gdi32
   extern BOOL        GetLogColorSpace(HCOLORSPACE,LPSTRUCTURE,DWORD) gdi32 ;
                   from "GetLogColorSpaceA"
   extern HCOLORSPACE CreateColorSpace(LPSTRUCTURE) gdi32 ;
                   from "CreateColorSpaceA"
   extern BOOL        SetColorSpace(HDC,HCOLORSPACE) gdi32
   extern BOOL        DeleteColorSpace(HCOLORSPACE) gdi32
   extern BOOL        GetICMProfile(HDC,LPDWORD,LPSTR) gdi32 ;
                   from "GetICMProfileA"
   extern BOOL        SetICMProfile(HDC,LPSTR) gdi32 ;
                   from "SetICMProfileA"
   extern BOOL        GetDeviceGammaRamp(HDC,LPVOID) gdi32
   extern BOOL        SetDeviceGammaRamp(HDC,LPVOID) gdi32
   extern BOOL        ColorMatchToTarget(HDC,HDC,DWORD) gdi32
   extern BOOL        UpdateICMRegKey(DWORD, DWORD, LPSTR, UINT) gdi32 ;
                   from "UpdateICMRegKeyA"
   extern CINT        EnumICMProfiles(HDC,FARPROC,LPARAM) gdi32 ;
                   from "EnumICMProfilesA"
   // End wingdi.h
return null

function ExternUser
   //--------------------------------------------------------------
   //
   //  Adapted from winuser.h 
   //  USER procedure declarations, constant definitions 
   //  and macros
   //
   //--------------------------------------------------------------

   extern CINT        wvsprintf(LPSTR, LPCSTR, va_list) user32 ;
                   from "wvsprintfA"

   //
   //  This needs to be    externed once for each possible combination
   //  of parameters.
   //
   //   extern cdecl CINT  wsprintf(LPSTR, LPCSTR, ...) user32 ;
   //                   from "wsprintfA"

   extern HKL         LoadKeyboardLayout(LPCSTR, UINT) user32 ;
                   from "LoadKeyboardLayoutA"

   if 'NT' $ os(1)
      extern BOOL        ActivateKeyboardLayout(HKL, UINT) user32
      extern CINT        ToUnicodeEx(UINT, UINT, PBYTE, LPWSTR, CINT, ;
                         UINT, HKL) user32
   else
      extern HKL         ActivateKeyboardLayout(HKL, UINT) user32
   endif

   extern BOOL        UnloadKeyboardLayout(HKL) user32
   extern BOOL        GetKeyboardLayoutName(LPSTR) user32 ;
                   from "GetKeyboardLayoutNameA"
   extern CINT        GetKeyboardLayoutList(CINT, CPTR) user32
   extern HKL         GetKeyboardLayout(DWORD) user32

   extern HDESK       CreateDesktop(LPSTR, LPSTR, LPSTRUCTURE, DWORD, ;
                   DWORD, LPSTRUCTURE) user32 ;
                   from "CreateDesktopA"
   extern HDESK       OpenDesktop(LPSTR, DWORD, BOOL, DWORD) user32 ;
                   from "OpenDesktopA"
   extern HDESK       OpenInputDesktop(DWORD, BOOL, DWORD) user32

   extern BOOL        EnumDesktops(HWINSTA, FARPROC, LPARAM) user32 ;
                   from "EnumDesktopsA"
   extern BOOL        EnumDesktopWindows(HDESK, FARPROC, LPARAM) user32
   extern BOOL        SwitchDesktop(HDESK) user32
   extern BOOL        SetThreadDesktop(HDESK) user32
   extern BOOL        CloseDesktop(HDESK) user32
   extern HDESK       GetThreadDesktop(DWORD) user32

   extern HWINSTA     CreateWindowStation(LPSTR, DWORD, DWORD, ;
                   LPSTRUCTURE) user32 ;
                   from "CreateWindowStationA"
   extern HWINSTA     OpenWindowStation(LPSTR, BOOL, DWORD) user32 ;
                   from "OpenWindowStationA"
   extern BOOL        EnumWindowStations(FARPROC, LPARAM) user32 ;
                   from "EnumWindowStationsA"
   extern BOOL        CloseWindowStation(HWINSTA) user32
   extern BOOL        SetProcessWindowStation(HWINSTA) user32
   extern HWINSTA     GetProcessWindowStation(VOID) user32
   extern BOOL        SetUserObjectSecurity(HANDLE, LPSTRUCTURE, ;
                   LPSTRUCTURE) user32
   extern BOOL        GetUserObjectSecurity(HANDLE, LPSTRUCTURE, LPSTRUCTURE, ;
                   DWORD, LPDWORD) user32

   extern BOOL        GetUserObjectInformationA(HANDLE, CINT, PVOID, ;
                   DWORD, LPDWORD) user32
   extern BOOL        SetUserObjectInformation(HANDLE, CINT, PVOID, DWORD) user32 ;
                   from "SetUserObjectInformationA"

   extern UINT        RegisterWindowMessage(LPCSTR) user32 ;
                   from "RegisterWindowMessageA"

   extern BOOL        DrawEdge(HDC, LPSTRUCTURE, UINT, UINT) user32
   extern BOOL        DrawFrameControl(HDC, LPSTRUCTURE, UINT, UINT) user32
   extern BOOL        DrawCaption(HWND, HDC, LPSTRUCTURE, UINT) user32
   extern BOOL        DrawAnimatedRects(HWND, CINT, LPSTRUCTURE, ;
                   LPSTRUCTURE) user32

   //
   // Message Function Templates
   //

   extern BOOL        GetMessage(LPSTRUCTURE, HWND, UINT, UINT) user32 ;
                   from "GetMessageA"
   extern BOOL        TranslateMessage(CPTR) user32
   extern LONG        DispatchMessage(CPTR) user32 ;
                   from "DispatchMessageA"
   extern BOOL        SetMessageQueue(CINT) user32
   extern BOOL        PeekMessage(LPSTRUCTURE, HWND, UINT, UINT, UINT) user32 ;
                   from "PeekMessageA"
   extern BOOL        RegisterHotKey(HWND, CINT, UINT, UINT) user32
   extern BOOL        UnregisterHotKey(HWND, CINT) user32
   extern BOOL        ExitWindowsEx(UINT, DWORD) user32
   extern BOOL        SwapMouseButton(BOOL) user32
   extern DWORD       GetMessagePos(VOID) user32
   extern LONG        GetMessageTime(VOID) user32
   extern LONG        GetMessageExtraInfo(VOID) user32
   extern LRESULT     SendMessage(HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "SendMessageA"
   extern LRESULT     SendMessageTimeout(HWND, UINT, WPARAM, LPARAM, UINT, ;
                   UINT, LPDWORD) user32 ;
                   from "SendMessageTimeoutA"
   extern BOOL        SendNotifyMessage(HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "SendNotifyMessageA"
   extern BOOL        SendMessageCallback(HWND, UINT, WPARAM, LPARAM, ;
                   FARPROC, DWORD) user32 ;
                   from "SendMessageCallbackA"
   extern LONG        BroadcastSystemMessage(DWORD, LPDWORD, UINT, ;
                   WPARAM, LPARAM) user32
   extern BOOL        PostMessage(HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "PostMessageA"
   extern BOOL        PostThreadMessage(DWORD, UINT, WPARAM, LPARAM) user32 ;
                   from "PostThreadMessageA"
   extern BOOL        AttachThreadInput(DWORD, DWORD, BOOL) user32
   extern BOOL        ReplyMessage(LRESULT) user32
   extern BOOL        WaitMessage(VOID) user32
   extern DWORD       WaitForInputIdle(HANDLE, DWORD) user32
   extern LRESULT     DefWindowProc(HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "DefWindowProcA"
   extern VOID        PostQuitMessage(CINT) user32
   extern LRESULT     CallWindowProc(FARPROC, HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "CallWindowProcA"
   extern LRESULT     CallWindowProc(FARPROC, HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "CallWindowProcA"
   extern BOOL        InSendMessage(VOID) user32

   extern UINT        GetDoubleClickTime(VOID) user32
   extern BOOL        SetDoubleClickTime(UINT) user32
   extern ATOM        RegisterClass(LPSTRUCTURE) user32 ;
                   from "RegisterClassA"
   extern BOOL        UnregisterClass(LPCSTR, HINSTANCE) user32 ;
                   from "UnregisterClassA"
   extern BOOL        GetClassInfo(HINSTANCE, LPCSTR, LPSTRUCTURE) user32 ;
                   from "GetClassInfoA"
   extern ATOM        RegisterClassEx(LPSTRUCTURE) user32 ;
                   from "RegisterClassExA"
   extern BOOL        GetClassInfoEx(HINSTANCE, LPCSTR, LPSTRUCTURE) user32 ;
                   from "GetClassInfoExA"

   extern HWND        CreateWindowEx(DWORD, LPCSTR, LPCSTR, DWORD, CINT, ;
                   CINT, CINT, CINT, HWND, HMENU, HINSTANCE, LPVOID) user32 ;
                   from "CreateWindowExA"
   extern BOOL        IsWindow(HWND) user32
   extern BOOL        IsMenu(HMENU) user32
   extern BOOL        IsChild(HWND, HWND) user32
   extern BOOL        DestroyWindow(HWND) user32
   extern BOOL        ShowWindow(HWND, CINT) user32
   extern BOOL        ShowWindowAsync(HWND, CINT) user32
   extern BOOL        FlashWindow(HWND, BOOL) user32
   extern BOOL        ShowOwnedPopups(HWND, BOOL) user32
   extern BOOL        OpenIcon(HWND) user32
   extern BOOL        CloseWindow(HWND) user32
   extern BOOL        MoveWindow(HWND, CINT, CINT, CINT, CINT, BOOL) user32
   extern BOOL        SetWindowPos(HWND, HWND, CINT, CINT, CINT, ;
                   CINT, UINT) user32
   extern BOOL        GetWindowPlacement(HWND, LPSTRUCTURE) user32
   extern BOOL        SetWindowPlacement(HWND, LPSTRUCTURE) user32
   extern HWND        BeginDeferWindowPos(CINT) user32
   extern HWND        DeferWindowPos(HWND, HWND, HWND, CINT, CINT, ;
                   CINT, CINT, UINT) user32
   extern BOOL        EndDeferWindowPos(HWND) user32
   extern BOOL        IsWindowVisible(HWND) user32
   extern BOOL        IsIconic(HWND) user32
   extern BOOL        AnyPopup(VOID) user32
   extern BOOL        BringWindowToTop(HWND) user32
   extern BOOL        IsZoomed(HWND) user32

   extern HWND        CreateDialogParam(HINSTANCE, LPCSTR, HWND, ;
                   FARPROC, LPARAM) user32 ;
                   from "CreateDialogParamA"
   extern HWND        CreateDialogIndirectParam(HINSTANCE, LPSTRUCTURE, HWND, ;
                   FARPROC, LPARAM) user32 ;
                   from "CreateDialogIndirectParamA"
   extern CINT        DialogBoxParamA(HINSTANCE, LPCSTR, HWND, ;
                   FARPROC, LPARAM) user32
   extern CINT        DialogBoxIndirectParam(HINSTANCE, LPSTRUCTURE, ;
                   HWND, FARPROC, LPARAM) user32 ;
                   from "DialogBoxIndirectParamA"

   #define DialogBox(hInstance, lpTemplate, hWndParent, lpDialogFunc) DialogBoxParam(hInstance, lpTemplate, hWndParent, lpDialogFunc, 0)
   #define DialogBoxIndirect(hInstance, lpTemplate, hWndParent, lpDialogFunc) DialogBoxIndirectParam(hInstance, lpTemplate, hWndParent, lpDialogFunc, 0)

   extern BOOL        EndDialog(HWND, CINT) user32
   extern HWND        GetDlgItem(HWND, CINT) user32
   extern BOOL        SetDlgItemInt(HWND, CINT, UINT, BOOL) user32
   extern UINT        GetDlgItemInt(HWND, CINT, LPBOOL, BOOL) user32

   extern BOOL        SetDlgItemText(HWND, CINT, LPCSTR) user32 ;
                   from "SetDlgItemTextA"
   extern UINT        GetDlgItemText(HWND, CINT, LPSTR, CINT) user32 ;
                   from "GetDlgItemTextA"
   extern BOOL        CheckDlgButton(HWND, CINT, UINT) user32
   extern BOOL        CheckRadioButton(HWND, CINT, CINT, CINT) user32
   extern UINT        IsDlgButtonChecked(HWND, CINT) user32
   extern LONG        SendDlgItemMessage(HWND, CINT, UINT, WPARAM, ;
                   LPARAM) user32 ;
                   from "SendDlgItemMessageA"
   extern HWND        GetNextDlgGroupItem(HWND, HWND, BOOL) user32
   extern HWND        GetNextDlgTabItem(HWND, HWND, BOOL) user32
   extern CINT        GetDlgCtrlID(HWND) user32
   extern CLONG       GetDialogBaseUnits(VOID) user32
   extern LRESULT     DefDlgProc(HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "DefDlgProcA"
   extern BOOL        CallMsgFilter(LPSTRUCTURE, CINT) user32 ;
                   from "CallMsgFilterA"
   extern BOOL        OpenClipboard(HWND) user32
   extern BOOL        CloseClipboard(VOID) user32
   extern HWND        GetClipboardOwner(VOID) user32
   extern HWND        SetClipboardViewer(HWND) user32
   extern HWND        GetClipboardViewer(VOID) user32
   extern BOOL        ChangeClipboardChain(HWND, HWND) user32
   extern HANDLE      SetClipboardData(UINT, HANDLE) user32
   extern HANDLE      GetClipboardData(UINT) user32
   extern UINT        RegisterClipboardFormat(LPCSTR) user32 ;
                   from "RegisterClipboardFormatA"
   extern CINT        CountClipboardFormats(VOID) user32
   extern UINT        EnumClipboardFormats(UINT) user32
   extern CINT        GetClipboardFormatName(UINT, LPSTR, CINT) user32 ;
                   from "GetClipboardFormatNameA"
   extern BOOL        EmptyClipboard(VOID) user32
   extern BOOL        IsClipboardFormatAvailable(UINT) user32
   extern CINT        GetPriorityClipboardFormat(PUINT, CINT) user32
   extern HWND        GetOpenClipboardWindow(VOID) user32

   //
   // Character Translation Routines
   //

   extern BOOL        CharToOem(LPCSTR, LPSTR) user32 ;
                   from "CharToOemA"
   extern BOOL        OemToChar(LPCSTR, LPSTR) user32 ;
                   from "OemToCharA"
   extern BOOL        CharToOemBuff(LPCSTR, LPSTR, DWORD) user32 ;
                   from "CharToOemBuffA"
   extern BOOL        OemToCharBuff(LPCSTR, LPSTR, DWORD) user32 ;
                   from "OemToCharBuffA"
   extern LPSTR       CharUpper(LPSTR) user32 ;
                   from "CharUpperA"
   extern DWORD       CharUpperBuff(LPSTR, DWORD) user32 ;
                   from "CharUpperBuffA"
   extern LPSTR       CharLower(LPSTR) user32 ;
                   from "CharLowerA"
   extern DWORD       CharLowerBuff(LPSTR, DWORD) user32 ;
                   from "CharLowerBuffA"
   extern LPSTR       CharNext(LPCSTR) user32 ;
                   from "CharNextA"
   extern LPSTR       CharPrev(LPCSTR, LPCSTR) user32 ;
                   from "CharPrevA"
   extern LPSTR       CharNextEx(WORD, LPCSTR, DWORD) user32 ;
                   from "CharNextExA"
   extern LPSTR       CharPrevEx(WORD, LPCSTR, LPCSTR, DWORD) user32 ;
                   from "CharPrevExA"

   #define AnsiToOem CharToOem
   #define OemToAnsi OemToChar
   #define AnsiToOemBuff CharToOemBuff
   #define OemToAnsiBuff OemToCharBuff
   #define AnsiUpper CharUpper
   #define AnsiUpperBuff CharUpperBuff
   #define AnsiLower CharLower
   #define AnsiLowerBuff CharLowerBuff
   #define AnsiNext CharNext
   #define AnsiPrev CharPrev

   //
   // Language dependent Routines
   //
   extern BOOL        IsCharAlpha(CHAR) user32 ;
                   from "IsCharAlphaA"
   extern BOOL        IsCharAlphaNumeric(CHAR) user32 ;
                   from "IsCharAlphaNumericA"
   extern BOOL        IsCharUpperA(CHAR) user32
   extern BOOL        IsCharLowerA(CHAR) user32
   extern HWND        SetFocus(HWND) user32
   extern HWND        GetActiveWindow(VOID) user32
   extern HWND        GetFocus(VOID) user32
   extern UINT        GetKBCodePage(VOID) user32
   extern SHORT       GetKeyState(CINT) user32
   extern SHORT       GetAsyncKeyState(CINT) user32
   extern BOOL        GetKeyboardState(PBYTE) user32
   extern BOOL        SetKeyboardState(LPBYTE) user32
   extern CINT        GetKeyNameText(LONG, LPSTR, CINT) user32 ;
                   from "GetKeyNameTextA"
   extern CINT        GetKeyboardType(CINT) user32
   extern CINT        ToAscii(UINT, UINT, PBYTE, LPWORD, UINT) user32
   extern CINT        ToAsciiEx(UINT, UINT, PBYTE, LPWORD, UINT, HKL) user32
   extern CINT        ToUnicode(UINT, UINT, PBYTE, LPWSTR, CINT, UINT) user32
   extern DWORD       OemKeyScan(WORD) user32
   extern SHORT       VkKeyScan(CHAR) user32 ;
                   from "VkKeyScanA"
   extern SHORT       VkKeyScanEx(CHAR, HKL) user32 ;
                   from "VkKeyScanExA"
   extern VOID        keybd_event(BYTE, BYTE, DWORD, DWORD) user32
   extern VOID        mouse_event(DWORD, DWORD, DWORD, DWORD, DWORD) user32
   extern UINT        MapVirtualKey(UINT, UINT) user32 ;
                   from "MapVirtualKeyA"
   extern UINT        MapVirtualKeyEx(UINT, UINT, HKL) user32 ;
                   from "MapVirtualKeyExA"
   extern BOOL        GetInputState(VOID) user32
   extern DWORD       GetQueueStatus(UINT) user32
   extern HWND        GetCapture(VOID) user32
   extern HWND        SetCapture(HWND) user32
   extern BOOL        ReleaseCapture(VOID) user32
   extern DWORD       MsgWaitForMultipleObjects(DWORD, LPHANDLE, BOOL, ;
                   DWORD, DWORD) user32

   //
   // Windows Functions
   //

   extern UINT        SetTimer(HWND, UINT, UINT, FARPROC) user32
   extern BOOL        KillTimer(HWND, UINT) user32
   extern BOOL        IsWindowUnicode(HWND) user32
   extern BOOL        EnableWindow(HWND, BOOL) user32
   extern BOOL        IsWindowEnabled(HWND) user32
   extern HACCEL      LoadAccelerators(HINSTANCE, LPCSTR) user32 ;
                   from "LoadAcceleratorsA"
   extern HACCEL      CreateAcceleratorTable(LPSTRUCTURE, CINT) user32 ;
                   from "CreateAcceleratorTableA"
   extern BOOL        DestroyAcceleratorTable(HACCEL) user32
   extern CINT        CopyAcceleratorTable(HACCEL, LPSTRUCTURE, CINT) user32 ;
                   from "CopyAcceleratorTableA"
   extern CINT        TranslateAccelerator(HWND, HACCEL, LPSTRUCTURE) user32 ;
                   from "TranslateAcceleratorA"
   extern CINT        GetSystemMetrics(CINT) user32
   extern HMENU       LoadMenu(HINSTANCE, LPCSTR) user32 ;
                   from "LoadMenuA"
   extern HMENU       LoadMenuIndirect(LPSTRUCTURE) user32 ;
                   from "LoadMenuIndirectA"
   extern HMENU       GetMenu(HWND) user32
   extern BOOL        SetMenu(HWND, HMENU) user32
   extern BOOL        ChangeMenu(HMENU, UINT, LPCSTR, UINT, UINT) user32 ;
                   from "ChangeMenuA"
   extern BOOL        HiliteMenuItem(HWND, HMENU, UINT, UINT) user32
   extern CINT        GetMenuString(HMENU, UINT, LPSTR, CINT, UINT) user32 ;
                   from "GetMenuStringA"
   extern UINT        GetMenuState(HMENU, UINT, UINT) user32
   extern BOOL        DrawMenuBar(HWND) user32
   extern HMENU       GetSystemMenu(HWND, BOOL) user32
   extern HMENU       CreateMenu(VOID) user32
   extern HMENU       CreatePopupMenu(VOID) user32
   extern BOOL        DestroyMenu(HMENU) user32
   extern DWORD       CheckMenuItem(HMENU, UINT, UINT) user32
   extern BOOL        EnableMenuItem(HMENU, UINT, UINT) user32
   extern HMENU       GetSubMenu(HMENU, CINT) user32
   extern UINT        GetMenuItemID(HMENU, CINT) user32
   extern CINT        GetMenuItemCount(HMENU) user32
   extern BOOL        InsertMenu(HMENU, UINT, UINT, UINT, LPCSTR) user32 ;
                   from "InsertMenuA"
   extern BOOL        AppendMenu(HMENU, UINT, UINT, LPCSTR) user32 ;
                   from "AppendMenuA"
   extern BOOL        ModifyMenu(HMENU, UINT, UINT, UINT, LPCSTR) user32 ;
                   from "ModifyMenuA"
   extern BOOL        RemoveMenu(HMENU, UINT, UINT) user32
   extern BOOL        DeleteMenu(HMENU, UINT, UINT) user32
   extern BOOL        SetMenuItemBitmaps(HMENU, UINT, UINT, ;
                   HBITMAP, HBITMAP) user32
   extern LONG        GetMenuCheckMarkDimensions(VOID) user32
   extern BOOL        TrackPopupMenu(HMENU, UINT, CINT, CINT, CINT, HWND, ;
                   LPSTRUCTURE) user32
   extern BOOL        TrackPopupMenuEx(HMENU, UINT, CINT, CINT, ;
                   HWND, LPSTRUCTURE) user32
   extern BOOL        InsertMenuItem(HMENU, UINT, BOOL, LPSTRUCTURE) user32 ;
                   from "InsertMenuItemA"
   extern BOOL        GetMenuItemInfo(HMENU, UINT, BOOL, LPSTRUCTURE) user32 ;
                   from "GetMenuItemInfoA"
   extern BOOL        SetMenuItemInfo(HMENU, UINT, BOOL, LPSTRUCTURE) user32 ;
                   from "SetMenuItemInfoA"

   extern UINT        GetMenuDefaultItem(HMENU, UINT, UINT) user32
   extern BOOL        SetMenuDefaultItem(HMENU, UINT, UINT) user32

   extern BOOL        GetMenuItemRect(HWND, HMENU, UINT, LPSTRUCTURE) user32
   extern CINT        MenuItemFromPoint(HWND, HMENU, LPSTRUCTURE) user32

   extern DWORD       DragObject(HWND, HWND, UINT, DWORD, HCURSOR) user32
   extern BOOL        DragDetect(HWND, LPSTRUCTURE) user32

   extern BOOL        DrawIcon(HDC, CINT, CINT, HICON) user32
   extern CINT        DrawText(HDC, LPCSTR, CINT, LPSTRUCTURE, UINT) user32 ;
                   from "DrawTextA"
   extern CINT        DrawTextEx(HDC, LPSTR, CINT, LPSTRUCTURE, ;
                   UINT, LPSTRUCTURE) user32 ;
                   from "DrawTextExA"
   extern BOOL        GrayString(HDC, HBRUSH, FARPROC, LPARAM, CINT, CINT, ;
                   CINT, CINT, CINT) user32 ;
                   from "GrayStringA"

   extern BOOL        DrawState(HDC, HBRUSH, FARPROC, LPARAM, WPARAM, CINT, ;
                   CINT, CINT, CINT, UINT) user32 ;
                   from "DrawStateA"
   extern LONG        TabbedTextOut(HDC, CINT, CINT, LPCSTR, CINT, CINT, ;
                   LPINT, CINT) user32 ;
                   from "TabbedTextOutA"
   extern DWORD       GetTabbedTextExtent(HDC, LPCSTR, CINT, CINT, LPINT) user32 ;
                   from "GetTabbedTextExtentA"
   extern BOOL        UpdateWindow(HWND) user32
   extern HWND        SetActiveWindow(HWND) user32
   extern HWND        GetForegroundWindow(VOID) user32
   extern BOOL        SetForegroundWindow(HWND) user32
   extern HWND        WindowFromDC(HDC) user32
   extern HDC         GetDC(HWND) user32
   extern HDC         GetDCEx(HWND, HRGN, DWORD) user32
   extern HDC         GetWindowDC(HWND) user32
   extern CINT        ReleaseDC(HWND, HDC) user32
   extern HDC         BeginPaint(HWND, LPSTRUCTURE) user32
   extern BOOL        EndPaint(HWND, LPSTRUCTURE) user32
   extern BOOL        GetUpdateRect(HWND, LPSTRUCTURE, BOOL) user32
   extern CINT        GetUpdateRgn(HWND, HRGN, BOOL) user32
   extern CINT        SetWindowRgn(HWND, HRGN, BOOL) user32
   extern CINT        GetWindowRgn(HWND, HRGN) user32
   extern CINT        ExcludeUpdateRgn(HDC, HWND) user32
   extern BOOL        InvalidateRect(HWND, LPSTRUCTURE, BOOL) user32
   extern BOOL        ValidateRect(HWND, LPSTRUCTURE) user32
   extern BOOL        InvalidateRgn(HWND, HRGN, BOOL) user32
   extern BOOL        ValidateRgn(HWND, HRGN) user32
   extern BOOL        RedrawWindow(HWND, LPSTRUCTURE, HRGN, UINT) user32

   //
   // LockWindowUpdate API
   //

   extern BOOL        LockWindowUpdate(HWND) user32
   extern BOOL        ScrollWindow(HWND, CINT, CINT, LPSTRUCTURE, ;
                   LPSTRUCTURE) user32
   extern BOOL        ScrollDC(HDC, CINT, CINT, LPSTRUCTURE, LPSTRUCTURE, ;
                   HRGN, LPRECT) user32
   extern CINT        ScrollWindowEx(HWND, CINT, CINT, LPSTRUCTURE, ;
                   LPSTRUCTURE, HRGN, LPSTRUCTURE, UINT) user32
   extern CINT        SetScrollPos(HWND, CINT, CINT, BOOL) user32
   extern CINT        GetScrollPos(HWND, CINT) user32
   extern BOOL        SetScrollRange(HWND, CINT, CINT, CINT, BOOL) user32
   extern BOOL        GetScrollRange(HWND, CINT, LPINT, LPINT) user32
   extern BOOL        ShowScrollBar(HWND, CINT, BOOL) user32
   extern BOOL        EnableScrollBar(HWND, UINT, UINT) user32

   //  SetProp() conflicts with undocumented dBASE function
   extern BOOL        SetPropA(HWND, LPCSTR, HANDLE) user32 ;
                   from "SetPropA"
   extern HANDLE      GetProp(HWND, LPCSTR) user32 ;
                   from "GetPropA"
   extern HANDLE      RemoveProp(HWND, LPCSTR) user32 ;
                   from "RemovePropA"
   extern CINT        EnumPropsEx(HWND, FARPROC, LPARAM) user32 ;
                   from "EnumPropsExA"
   extern CINT        EnumProps(HWND, FARPROC) user32 ;
                   from "EnumPropsA"
   extern BOOL        SetWindowText(HWND, LPCSTR) user32 ;
                   from "SetWindowTextA"
   extern CINT        GetWindowText(HWND, LPSTR, CINT) user32 ;
                   from "GetWindowTextA"
   extern CINT        GetWindowTextLength(HWND) user32 ;
                   from "GetWindowTextLengthA"
   extern BOOL        GetClientRect(HWND, LPRECT) user32
   extern BOOL        GetWindowRect(HWND, LPRECT) user32
   extern BOOL        AdjustWindowRect(LPRECT, DWORD, BOOL) user32
   extern BOOL        AdjustWindowRectEx(LPRECT, DWORD, BOOL, DWORD) user32

   extern BOOL        SetWindowContextHelpId(HWND, DWORD) user32
   extern DWORD       GetWindowContextHelpId(HWND) user32
   extern BOOL        SetMenuContextHelpId(HMENU, DWORD) user32
   extern DWORD       GetMenuContextHelpId(HMENU) user32

   extern CINT        MessageBox(HWND, LPCSTR, LPCSTR, UINT) user32 ;
                   from "MessageBoxA"
   extern CINT        MessageBoxEx(HWND, LPCSTR, LPCSTR, UINT, WORD) user32 ;
                   from "MessageBoxExA"
   extern CINT        MessageBoxIndirect(LPSTRUCTURE) user32 ;
                   from "MessageBoxIndirectA"
   extern BOOL        MessageBeep(UINT) user32
   extern CINT        ShowCursor(BOOL) user32
   extern BOOL        SetCursorPos(CINT, CINT) user32
   extern HCURSOR     SetCursor(HCURSOR) user32
   extern BOOL        GetCursorPos(LPPOINT) user32
   extern BOOL        ClipCursor(LPSTRUCTURE) user32
   extern BOOL        GetClipCursor(LPRECT) user32
   extern HCURSOR     GetCursor(VOID) user32
   extern BOOL        CreateCaret(HWND, HBITMAP, CINT, CINT) user32
   extern UINT        GetCaretBlinkTime(VOID) user32
   extern BOOL        SetCaretBlinkTime(UINT) user32
   extern BOOL        DestroyCaret(VOID) user32
   extern BOOL        HideCaret(HWND) user32
   extern BOOL        ShowCaret(HWND) user32
   extern BOOL        SetCaretPos(CINT, CINT) user32
   extern BOOL        GetCaretPos(LPSTRUCTURE) user32
   extern BOOL        ClientToScreen(HWND, LPSTRUCTURE) user32
   extern BOOL        ScreenToClient(HWND, LPSTRUCTURE) user32
   extern CINT        MapWindowPoints(HWND, HWND, LPSTRUCTURE, UINT) user32
   extern HWND        WindowFromPoint(LPSTRUCTURE) user32
   extern HWND        ChildWindowFromPoint(HWND, LPSTRUCTURE) user32

   extern DWORD       GetSysColor(CINT) user32
   extern HBRUSH      GetSysColorBrush(CINT) user32
   extern BOOL        SetSysColors(CINT, LPINT, LPCOLORREF) user32
   extern BOOL        DrawFocusRect(HDC, LPSTRUCTURE) user32
   extern CINT        FillRect(HDC, LPSTRUCTURE, HBRUSH) user32
   extern CINT        FrameRect(HDC, LPSTRUCTURE, HBRUSH) user32
   extern BOOL        InvertRect(HDC, LPSTRUCTURE) user32
   extern BOOL        SetRect(LPSTRUCTURE, CINT, CINT, CINT, CINT) user32
   extern BOOL        SetRectEmpty(LPSTRUCTURE) user32
   extern BOOL        CopyRect(LPSTRUCTURE, LPSTRUCTURE) user32
   extern BOOL        InflateRect(LPSTRUCTURE, CINT, CINT) user32
   extern BOOL        IntersectRect(LPSTRUCTURE, LPSTRUCTURE, LPSTRUCTURE) user32
   extern BOOL        UnionRect(LPSTRUCTURE, LPSTRUCTURE, LPSTRUCTURE) user32
   extern BOOL        SubtractRect(LPSTRUCTURE, LPSTRUCTURE, LPSTRUCTURE) user32
   extern BOOL        OffsetRect(LPSTRUCTURE, CINT, CINT) user32
   extern BOOL        IsRectEmpty(LPSTRUCTURE) user32
   extern BOOL        EqualRect(LPSTRUCTURE, LPSTRUCTURE) user32
   extern BOOL        PtInRect(LPSTRUCTURE, LPSTRUCTURE) user32
   extern WORD        GetWindowWord(HWND, CINT) user32
   extern WORD        SetWindowWord(HWND, CINT, WORD) user32
   extern LONG        GetWindowLong(HWND, CINT) user32 ;
                   from "GetWindowLongA"
   extern LONG        SetWindowLong(HWND, CINT, LONG) user32 ;
                   from "SetWindowLongA"
   extern WORD        GetClassWord(HWND, CINT) user32
   extern WORD        SetClassWord(HWND, CINT, WORD) user32
   extern DWORD       GetClassLong(HWND, CINT) user32 ;
                   from "GetClassLongA"
   extern DWORD       SetClassLong(HWND, CINT, LONG) user32 ;
                   from "SetClassLongA"
   extern HWND        GetDesktopWindow(VOID) user32
   extern HWND        GetParent(HWND) user32
   extern HWND        SetParent(HWND, HWND) user32
   extern BOOL        EnumChildWindows(HWND, FARPROC, LPARAM) user32
   extern HWND        FindWindow(LPCSTR, LPCSTR) user32 ;
                   from "FindWindowA"
   extern HWND        FindWindowEx(HWND, HWND, LPCSTR, LPCSTR) user32 ;
                   from "FindWindowExA"
   extern BOOL        EnumWindows(FARPROC, LPARAM) user32
   extern BOOL        EnumThreadWindows(DWORD, FARPROC, LPARAM) user32
   extern CINT        GetClassName(HWND, LPSTR, CINT) user32 ;
                   from "GetClassNameA"
   extern HWND        GetTopWindow(HWND) user32
   extern DWORD       GetWindowThreadProcessId(HWND, LPDWORD) user32
   extern HWND        GetLastActivePopup(HWND) user32

   extern HWND        GetWindow(HWND, UINT) user32
   extern CLONG       SetWindowsHook(CINT, FARPROC) user32 ;
                   from "SetWindowsHookA"
   extern CLONG       SetWindowsHook(CINT, FARPROC) user32 ;
                   from "SetWindowsHookA"
   extern BOOL        UnhookWindowsHook(CINT, FARPROC) user32
   extern CLONG       SetWindowsHookEx(CINT, FARPROC, HINSTANCE, DWORD) user32 ;
                   from "SetWindowsHookExA"
   extern BOOL        UnhookWindowsHookEx(HHOOK) user32
   extern LRESULT     CallNextHookEx(HHOOK, CINT, WPARAM, LPARAM) user32

   extern BOOL        CheckMenuRadioItem(HMENU, UINT, UINT, UINT, UINT) user32

   //
   // Resource Loading Routines
   //

   extern HBITMAP     LoadBitmap(HINSTANCE, LPCSTR) user32 ;
                   from "LoadBitmapA"
   extern HCURSOR     LoadCursor(HINSTANCE, LPCSTR) user32 ;
                   from "LoadCursorA"
   extern HCURSOR     LoadCursorFromFile(LPCSTR) user32 ;
                   from "LoadCursorFromFileA"
   extern HCURSOR     CreateCursor(HINSTANCE, CINT, CINT, CINT, CINT, ;
                   LPVOID, LPVOID) user32
   extern BOOL        DestroyCursor(HCURSOR) user32

   extern BOOL        SetSystemCursor(HCURSOR, DWORD) user32
   extern HICON       LoadIcon(HINSTANCE, LPCSTR) user32 ;
                   from "LoadIconA"
   extern HICON       CreateIcon(HINSTANCE, CINT, CINT, BYTE, BYTE, ;
                   LPBYTE, LPBYTE) user32
   extern BOOL        DestroyIcon(HICON) user32
   extern CINT        LookupIconIdFromDirectory(PBYTE, BOOL) user32
   extern CINT        LookupIconIdFromDirectoryEx(PBYTE, BOOL, CINT, ;
                   CINT, UINT) user32
   extern HICON       CreateIconFromResource(PBYTE, DWORD, BOOL, DWORD) user32

   extern HICON       CreateIconFromResourceEx(PBYTE, DWORD, BOOL, DWORD, ;
                   CINT, CINT, UINT) user32

   extern HANDLE      LoadImage(HINSTANCE, LPCSTR, UINT, CINT, ;
                   CINT, UINT) user32 ;
                   from "LoadImageA"
   extern HICON       CopyImage(HANDLE, UINT, CINT, CINT, UINT) user32
   extern BOOL        DrawIconEx(HDC, CINT, CINT, HICON, CINT, CINT, ;
                   UINT, HBRUSH, UINT) user32
   extern HICON       CreateIconIndirect(LPSTRUCTURE) user32
   extern HICON       CopyIcon(HICON) user32
   extern BOOL        GetIconInfo(HICON, LPSTRUCTURE) user32

   extern CINT        LoadString(HINSTANCE, UINT, LPSTR, CINT) user32 ;
                   from "LoadStringA"

   extern BOOL        IsDialogMessage(HWND, LPSTRUCTURE) user32 ;
                   from "IsDialogMessageA"
   extern BOOL        MapDialogRect(HWND, LPRECT) user32
   extern CINT        DlgDirList(HWND, LPSTR, CINT, CINT, UINT) user32 ;
                   from "DlgDirListA"
   extern BOOL        DlgDirSelectEx(HWND, LPSTR, CINT, CINT) user32 ;
                   from "DlgDirSelectExA"
   extern CINT        DlgDirListComboBox(HWND, LPSTR, CINT, CINT, UINT) user32 ;
                   from "DlgDirListComboBoxA"
   extern BOOL        DlgDirSelectComboBoxEx(HWND, LPSTR, CINT, CINT) user32 ;
                   from "DlgDirSelectComboBoxExA"

   extern CINT        SetScrollInfo(HWND, CINT, LPSTRUCTURE, BOOL) user32
   extern BOOL        GetScrollInfo(HWND, CINT, LPSTRUCTURE) user32
   extern LRESULT     DefFrameProc(HWND, HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "DefFrameProcA"
   extern LRESULT     DefMDIChildProc(HWND, UINT, WPARAM, LPARAM) user32 ;
                   from "DefMDIChildProcA"
   extern BOOL        TranslateMDISysAccel(HWND, LPSTRUCTURE) user32
   extern UINT        ArrangeIconicWindows(HWND) user32
   extern HWND        CreateMDIWindow(LPSTR, LPSTR, DWORD, CINT, CINT, CINT, ;
                   CINT, HWND, HINSTANCE, LPARAM) user32 ;
                   from "CreateMDIWindowA"
   extern WORD        TileWindows(HWND, UINT, LPSTRUCTURE, UINT, CPTR) user32
   extern WORD        CascadeWindows(HWND, UINT, LPSTRUCTURE, UINT, CPTR) user32

   extern BOOL        WinHelp(HWND, LPCSTR, UINT, DWORD) user32 ;
                   from "WinHelpA"

   extern LONG        ChangeDisplaySettings(LPSTRUCTURE, DWORD) user32 ;
                   from "ChangeDisplaySettingsA"
   extern BOOL        EnumDisplaySettings(LPCSTR, DWORD, LPSTRUCTURE) user32 ;
                   from "EnumDisplaySettingsA"
   extern BOOL        SystemParametersInfo(UINT, UINT, PVOID, UINT) user32 ;
                   from "SystemParametersInfoA"

   extern VOID        SetDebugErrorLevel(DWORD) user32
   extern VOID        SetLastErrorEx(DWORD, DWORD) user32
   // End winuser.h
return null

function ExternRegistry
   //
   // BUILD Version: 0001  
   // 
   // Adapted from Winreg.h
   // Abstract:
   //     This module contains the function prototypes and constant, type and
   //     structure definitions for the Windows 32-Bit Registry API.
   //

   //
   // Requested Key access mask type.
   //

   #define ACCESS_MASK DWORD
   #define REGSAM ACCESS_MASK

   //
   // Type definitions.
   //
   #define HKEY HANDLE
   #define PHKEY PHANDLE

   #define val_context LPSTRUCTURE
   #define PVALCONTEXT LPSTRUCTURE
   #define PVALUE      LPSTRUCTURE
   #define PPVALUE     LPSTRUCTURE
   #define QUERYHANDLER  FARPROC
   #define PQUERYHANDLER FARPROC
   #define REG_PROVIDER LPSTRUCTURE
   #define PPROVIDER    LPSTRUCTURE
   #define VALENT       LPSTRUCTURE
   #define PVALENT      LPSTRUCTURE

   //
   // API Prototypes.
   //

   extern LONG        RegCloseKey (HKEY) advapi32
   extern LONG        RegConnectRegistry(LPSTR, HKEY, PHKEY) advapi32 ;
                   from "RegConnectRegistryA"
   extern LONG        RegCreateKey(HKEY, LPCSTR, PHKEY) advapi32 ;
                   from "RegCreateKeyA"
   extern LONG        RegCreateKeyEx(HKEY, LPCSTR, DWORD, LPSTR, DWORD, ;
                   REGSAM, LPSTRUCTURE, PHKEY, LPDWORD) advapi32 ;
                   from "RegCreateKeyExA"
   extern LONG        RegDeleteKey(HKEY, LPCSTR) advapi32 ;
                   from "RegDeleteKeyA"
   extern LONG        RegDeleteValue(HKEY, LPCSTR) advapi32 ;
                   from "RegDeleteValueA"
   extern LONG        RegEnumKey(HKEY, DWORD, LPSTR, DWORD) advapi32 ;
                   from "RegEnumKeyA"
   extern LONG        RegEnumKeyEx(HKEY, DWORD, LPSTR, LPDWORD, LPDWORD, ;
                   LPSTR, LPDWORD, LPSTRUCTURE) advapi32 ;
                   from "RegEnumKeyExA"
   extern LONG        RegEnumValue(HKEY, DWORD, LPSTR, LPDWORD, LPDWORD, ;
                   LPDWORD, LPBYTE, LPDWORD) advapi32 ;
                   from "RegEnumValueA"
   extern LONG        RegFlushKey(HKEY) advapi32
   extern LONG        RegGetKeySecurity(HKEY, LPSTRUCTURE, LPSTRUCTURE, ;
                   LPDWORD) advapi32
   extern LONG        RegLoadKey(HKEY, LPCSTR, LPCSTR) advapi32 ;
                   from "RegLoadKeyA"
   extern LONG        RegNotifyChangeKeyValue(HKEY, BOOL, DWORD, ;
                   HANDLE, BOOL) advapi32
   extern LONG        RegOpenKey(HKEY, LPCSTR, PHKEY) advapi32 ;
                   from "RegOpenKeyA"
   extern LONG        RegOpenKeyEx(HKEY, LPCSTR, DWORD, REGSAM, PHKEY) advapi32 ;
                   from "RegOpenKeyExA"
   extern LONG        RegQueryInfoKey(HKEY, LPSTR, LPDWORD, LPDWORD, LPDWORD, ;
                   LPDWORD, LPDWORD, LPDWORD, LPDWORD, LPDWORD, LPDWORD, ;
                   LPSTRUCTURE) advapi32 ;
                   from "RegQueryInfoKeyA"
   extern LONG        RegQueryValue(HKEY, LPCSTR, LPSTR, PLONG) advapi32 ;
                   from "RegQueryValueA"
   extern LONG        RegQueryMultipleValues(HKEY, PVALENT, DWORD, LPSTR, ;
                   LPDWORD) advapi32 ;
                   from "RegQueryMultipleValuesA"
   extern LONG        RegQueryValueEx(HKEY, LPCSTR, LPDWORD, LPDWORD, ;
                   LPBYTE, LPDWORD) advapi32 ;
                   from "RegQueryValueExA"
   extern LONG        RegReplaceKey(HKEY, LPCSTR, LPCSTR, LPCSTR) advapi32 ;
                   from "RegReplaceKeyA"
   extern LONG        RegRestoreKey(HKEY, LPCSTR, DWORD) advapi32 ;
                   from "RegRestoreKeyA"
   extern LONG        RegSaveKey(HKEY, LPCSTR, LPSTRUCTURE) advapi32 ;
                   from "RegSaveKeyA"
   extern LONG        RegSetKeySecurity (HKEY, SECURITY_INFORMATION, ;
                   PSECURITY_INFORMATION) advapi32
   extern LONG        RegSetValue(HKEY, LPCSTR, DWORD, LPCSTR, DWORD) advapi32 ;
                   from "RegSetValueA"
   extern LONG        RegSetValueEx(HKEY, LPCSTR, DWORD, DWORD, PBYTE, ;
                   DWORD) advapi32 ;
                   from "RegSetValueExA"
   extern LONG        RegUnLoadKey(HKEY, LPCSTR) advapi32 ;
                   from "RegUnLoadKeyA"

   //
   // Remoteable System Shutdown APIs
   //

   extern BOOL        InitiateSystemShutdown(LPSTR, LPSTR, DWORD, ;
                   BOOL, BOOL) advapi32 ;
                   from "InitiateSystemShutdownA"
   extern BOOL        AbortSystemShutdown(LPSTR) advapi32 ;
                   from "AbortSystemShutdownA"
   // End winreg.h
return null

function ExternNetwork
   // 
   // Adapted from winnetwk.h
   // 
   // Standard WINNET Header File for WIN32
   // 
   // User Mode -Win32
   // 
   #define NETRESOURCE   LPSTRUCTURE
   #define LPNETRESOURCE LPSTRUCTURE
  
   //
   //  Network Connections.
   // 

   extern DWORD       WNetAddConnection(LPCSTR, LPCSTR, LPCSTR) mpr.dll ;
                   from "WNetAddConnectionA"
   extern DWORD       WNetAddConnection2(LPNETRESOURCE, LPCSTR, LPCSTR, ;
                   DWORD) mpr.dll ;
                   from "WNetAddConnection2A"
   extern DWORD       WNetAddConnection3(HWND, LPNETRESOURCE, LPCSTR, ;
                   LPCSTR, DWORD) mpr.dll ;
                   from "WNetAddConnection3A"
   extern DWORD       WNetCancelConnection(LPCSTR, BOOL) mpr.dll ;
                   from "WNetCancelConnectionA"
   extern DWORD       WNetCancelConnection2(LPCSTR, DWORD, BOOL) mpr.dll ;
                   from "WNetCancelConnection2A"
   extern DWORD       WNetGetConnection(LPCSTR, LPSTR, LPDWORD) mpr.dll ;
                   from "WNetGetConnectionA"
   extern DWORD       WNetUseConnection(HWND, LPNETRESOURCE, LPCSTR, LPCSTR, ;
                   DWORD, LPSTR, LPDWORD, LPDWORD) mpr.dll ;
                   from "WNetUseConnectionA"
   extern DWORD       WNetSetConnection(LPCSTR, DWORD, LPVOID) mpr.dll ;
                   from "WNetSetConnectionA"

   //
   //  Network Connection Dialogs.
   // 
   extern DWORD       WNetConnectionDialog(HWND, DWORD) mpr.dll
   extern DWORD       WNetDisconnectDialog(HWND, DWORD) mpr.dll

   #define LPCONNECTDLGSTRUCT LPSTRUCTURE

   extern DWORD       WNetConnectionDialog1(LPCONNECTDLGSTRUCT) mpr.dll ;
                   from "WNetConnectionDialog1A"

   #define LPDISCDLGSTRUCT LPSTRUCTURE

   extern DWORD       WNetDisconnectDialog1(LPDISCDLGSTRUCT) mpr.dll ;
                   from "WNetDisconnectDialog1A"

   //
   //  Network Browsing.
   //

   extern DWORD       WNetOpenEnum(DWORD, DWORD, DWORD, LPNETRESOURCE, ;
                   LPHANDLE) mpr.dll ;
                   from "WNetOpenEnumA"
   extern DWORD       WNetEnumResource(HANDLE, LPDWORD, LPVOID, LPDWORD) mpr.dll ;
                   from "WNetEnumResourceA"
   extern DWORD       WNetCloseEnum(HANDLE) mpr.dll

   //
   //  Universal Naming.
   //

   #define LPUNIVERSAL_NAME_INFO
   #define LPREMOTE_NAME_INFO

   extern DWORD       WNetGetUniversalName(LPCSTR, DWORD, LPVOID, ;
                   LPDWORD) mpr.dll ;
                   from "WNetGetUniversalNameA"

   //
   //  Authentication and Logon/Logoff.
   //

   extern DWORD       WNetGetUser(LPCSTR, LPSTR, LPDWORD) mpr.dll ;
                   from "WNetGetUserA"

   //
   // Other.
   //

   extern DWORD       WNetGetProviderName(DWORD, LPSTR, LPDWORD) mpr.dll ;
                   from "WNetGetProviderNameA"

   #define LPNETINFOSTRUCT LPSTRUCTURE

   extern DWORD       WNetGetNetworkInformation(LPCSTR, LPNETINFOSTRUCT) mpr.dll ;
                   from "WNetGetNetworkInformationA"

   //
   //  User Profiles.
   //

   #define PFNGETPROFILEPATH   FARPROC
   #define PFNRECONCILEPROFILE FARPROC

   //
   //  Policies.
   //

   #define PFNPROCESSPOLICIES FARPROC

   //
   //  Error handling.
   // 

   extern DWORD       WNetGetLastError(LPDWORD, LPSTR, DWORD, LPSTR, ;
                   DWORD) mpr.dll ;
                   from "WNetGetLastErrorA"

   //
   //  For Shell
   //
  
   #define LPNETCONNECTINFOSTRUCT LPSTRUCTURE

   extern DWORD       MultinetGetConnectionPerformance(LPNETRESOURCE, ;
                   LPNETCONNECTINFOSTRUCT) mpr.dll ;
                   from "MultinetGetConnectionPerformanceA"
   // End winnetwk.h
return null

function ExternShell
   //---------------------------------------------------------------
   //
   // Adapted from shellapi.h 
   //
   // SHELL.DLL functions, types, and definitions 
   //
   //---------------------------------------------------------------

   #define HDROP  HANDLE

   extern UINT        DragQueryFile(HDROP,UINT,LPSTR,UINT) shell32 ;
                      from "DragQueryFileA"
   extern BOOL        DragQueryPoint(HDROP,LPSTRUCTURE) shell32
   extern VOID        DragFinish(HDROP) shell32
   extern VOID        DragAcceptFiles(HWND,BOOL) shell32

   extern HINSTANCE   ShellExecute(HWND, LPCSTR, LPCSTR, LPCSTR, ;
                      LPCSTR, CINT) shell32 ;
                      from "ShellExecuteA"
   extern HINSTANCE   FindExecutable(LPCSTR, LPCSTR, LPSTR) shell32 ;
                      from "FindExecutableA"

   extern CINT        ShellAbout(HWND, LPCSTR, LPCSTR, HICON) shell32 ;
                      from "ShellAboutA"
   extern HICON       DuplicateIcon(HINSTANCE, HICON) shell32
   extern HICON       ExtractAssociatedIcon(HINSTANCE, LPSTR, LPWORD) shell32 ;
                      from "ExtractAssociatedIconA"
   extern HICON       ExtractIcon(HINSTANCE, LPCSTR, UINT) shell32 ;
                      from "ExtractIconA"
   #define LPDRAGINFO LPSTRUCTURE

   //
   // AppBar stuff
   //
   #define PAPPBARDATA LPSTRUCTURE
   extern UINT        SHAppBarMessage(DWORD, PAPPBARDATA) shell32
   //
   //  EndAppBar
   //

   extern UINT        ExtractIconEx(LPCSTR, CINT, PHICON, PHICON, UINT) shell32 ;
                      from "ExtractIconExA"
 
   //
   // Shell File Operations
   //

   #define FILEOP_FLAGS     WORD
   #define LPSHFILEOPSTRUCT LPSTRUCTURE

   extern CINT        SHFileOperation(LPSHFILEOPSTRUCT) shell32 ;
                      from "SHFileOperationA"
   extern void        SHFreeNameMappings(HANDLE) shell32

   #define LPSHNAMEMAPPING LPSTRUCTURE

   //
   // End Shell File Operations
   //

   //
   //  Begin ShellExecuteEx and family
   //
   #define LPSHELLEXECUTEINFO LPSTRUCTURE

   extern BOOL        ShellExecuteEx(LPSHELLEXECUTEINFO) shell32 ;
                      from "ShellExecuteExA"
   //
   //  End ShellExecuteEx and family
   //

   //
   // Tray notification definitions
   //
   #define PNOTIFYICONDATA LPSTRUCTURE

   extern BOOL        Shell_NotifyIcon(DWORD, PNOTIFYICONDATA) shell32 ;
                      from "Shell_NotifyIconA"
   //
   // End Tray Notification Icons
   //

   //
   // Begin SHGetFileInfo
   //

   //
   // The SHGetFileInfo API provides an easy way to get attributes
   // for a file given a pathname.
   //
   //   PARAMETERS
   //
   //     pszPath              file name to get info about
   //     dwFileAttributes     file attribs, only used with SHGFI_USEFILEATTRIBUTES
   //     psfi                 place to return file info
   //     cbFileInfo           size of structure
   //     uFlags               flags
   //
   //   RETURN
   //     TRUE if things worked
   //

   #define LPSHFILEINFO LPSTRUCTURE
  
   extern DWORD       SHGetFileInfo(LPCSTR, DWORD, LPSHFILEINFO, ;
                     UINT, UINT) shell32 ;
                      from "SHGetFileInfoA"

   //
   // End SHGetFileInfo
   //
   // End shellapi.h
return null

function ExternDialog
   //--------------------------------------------------------------
   //
   //   Adapted from commdlg.h 
   //
   //   This module defines the 32-Bit Common Dialog APIs
   //
   //--------------------------------------------------------------

   #define LPOPENFILENAME LPSTRUCTURE

   extern BOOL        GetOpenFileName(LPOPENFILENAME) comdlg32.dll ;
                      from "GetOpenFileNameA"
   extern BOOL        GetSaveFileName(LPOPENFILENAME) comdlg32.dll ;
                      from "GetSaveFileNameA"
   extern short       GetFileTitle(LPCSTR, LPSTR, WORD) comdlg32.dll ;
                      from "GetFileTitleA"

   #define LPCHOOSECOLOR LPSTRUCTURE

   extern BOOL        ChooseColor(LPCHOOSECOLOR) comdlg32.dll ;
                      from "ChooseColorA"

   #define LPFINDREPLACE LPSTRUCTURE

   extern HWND        FindText(LPFINDREPLACE) comdlg32.dll ;
                      from "FindTextA"
   extern HWND        ReplaceText(LPFINDREPLACE) comdlg32.dll ;
                      from "ReplaceTextA"

   #define LPCHOOSEFONT LPSTRUCTURE

   extern BOOL        ChooseFont(LPCHOOSEFONT) comdlg32.dll ;
                      from "ChooseFontA"

   #define LPPRINTDLG LPSTRUCTURE

   extern BOOL        PrintDlg(LPPRINTDLG) comdlg32.dll ;
                      from "PrintDlgA"

   extern DWORD       CommDlgExtendedError(VOID) comdlg32.dll

   #define LPPAGESETUPDLG LPSTRUCTURE

   extern BOOL        PageSetupDlg( LPPAGESETUPDLG ) comdlg32.dll ;
                      from "PageSetupDlgA"
   // End commdlg.h
return null

